@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  Base - class that host scripts and contain static script functions
  This class is also responsible for garbage collection of scripting objects
@@ -32,18 +46,18 @@
 #include "version.h"
 #include <string.h>
 #include <stdlib.h>
-#include <cpdf.h>
-#include <cannotation.h>
-#include <delinearizator.h> 
-#include <factories.h> 
-#include <pdfwriter.h> 
+#include <kernel/cpdf.h>
+#include <kernel/cannotation.h>
+#include <kernel/delinearizator.h>
+#include <kernel/factories.h>
+#include <kernel/pdfwriter.h>
 #include <qdir.h>
 #include <qfile.h>
 #include <qdatetime.h>
 #include <qsinterpreter.h>
 #include <utils/debug.h>
-#include <textoutput.h>
-#include <cpage.h>
+#include <kernel/textoutput.h>
+#include <kernel/cpage.h>
 
 namespace gui {
 
@@ -56,7 +70,7 @@ using namespace pdfobjects;
 typedef vector<size_t> PageNums;
 
 /**
- Create new Base class 
+ Create new Base class
 */
 Base::Base() : BaseCore() {
  //Autodelete is on
@@ -202,10 +216,10 @@ int Base::runScriptList(const QStringList &initScripts) {
   QString initScriptFilename=initScripts[i];
   //guiPrintDbg(debug::DBG_INFO,"Considering init script: " << initScriptFilename);
   //Check if the script exists. If not, it is silently skipped
-  if (exists(initScriptFilename)) {   
+  if (exists(initScriptFilename)) {
    guiPrintDbg(debug::DBG_INFO,"Running init script: " << Q_OUT(initScriptFilename));
    //Any document-related classes are NOT available to the initscript, as no document is currently loaded
-   if (!runFile(initScriptFilename)) {  
+   if (!runFile(initScriptFilename)) {
     errorMessage();
     guiPrintDbg(debug::DBG_INFO,"Error running file: " << Q_OUT(initScriptFilename));
     conPrintError(tr("Error running")+" "+initScriptFilename);
@@ -246,7 +260,7 @@ void Base::runScriptsFromPath(const QStringList &initScriptPaths) {
   QString initScriptFilename=it.data();
   guiPrintDbg(debug::DBG_INFO,"Running init script: " << Q_OUT(initScriptFilename));
   //Any document-related classes are NOT available to the initscript, as no document is currently loaded
-  if (!runFile(initScriptFilename)) {  
+  if (!runFile(initScriptFilename)) {
    errorMessage();
    guiPrintDbg(debug::DBG_INFO,"Error running file: " << Q_OUT(initScriptFilename));
    conPrintError(tr("Error running")+" "+initScriptFilename);
@@ -280,7 +294,7 @@ QSPdfOperator* Base::createOperator(const QString &text,QSIPropertyArray* parame
  PdfOperator::Operands param;
  parameters->copyTo(param);
  boost::shared_ptr<SimpleGenericOperator> op(new SimpleGenericOperator(opTxt,param));
- return new QSPdfOperator(op,this); 
+ return new QSPdfOperator(op,this);
 }
 
 /**
@@ -298,13 +312,13 @@ QSPdfOperator* Base::createOperator(const QString &text,QObject* parameters) {
 
 /**
  Create new operator of type UnknownCompositePdfOperator
- @param beginText Start operator name text representation. 
+ @param beginText Start operator name text representation.
  @param endText End operator name text representation.
  @return new PDF operator
 */
 QSPdfOperator* Base::createCompositeOperator(const QString &beginText,const QString &endText) {
  boost::shared_ptr<UnknownCompositePdfOperator> op(new UnknownCompositePdfOperator(beginText,endText));
- return new QSPdfOperator(op,this); 
+ return new QSPdfOperator(op,this);
 }
 
 /**
@@ -312,7 +326,7 @@ QSPdfOperator* Base::createCompositeOperator(const QString &beginText,const QStr
  @return new empty PDF operator
 */
 QSPdfOperator* Base::createEmptyOperator() {
- return new QSPdfOperator(this); 
+ return new QSPdfOperator(this);
 }
 
 /**
@@ -332,7 +346,7 @@ QSAnnotation* Base::createAnnotation(QVariant rect,const QString &type) {
   ++it;
   ++i;
  }
- Rectangle rc(tm[0],tm[1],tm[2],tm[3]);
+ libs::Rectangle rc(tm[0],tm[1],tm[2],tm[3]);
  boost::shared_ptr<CPage> nullPage;
  boost::shared_ptr<CAnnotation> annot=CAnnotation::createAnnotation(rc,util::convertFromUnicode(type,util::PDF));
  return new QSAnnotation(annot,nullPage,this);
@@ -456,17 +470,17 @@ bool Base::delinearize(const QString &inFile,const QString &outFile) {
   if (ret) {
    const char *whatWasWrong=strerror(ret);
    lastErrorMessage=whatWasWrong;
-  } 
+  }
 //  guiPrintDbg(debug::DBG_DBG,"deleting pdf writer");
 //  if (wr) delete wr;
   guiPrintDbg(debug::DBG_DBG,"deleting delinearizator");
-  if (delin) delete delin;  
+  if (delin) delete delin;
   guiPrintDbg(debug::DBG_DBG,"Delinearizator exit");
   return (ret==0);
  } catch (...) {
   //This is the case of failure ..
   if (wr) delete wr;
-  if (delin) delete delin;  
+  if (delin) delete delin;
   return false;
  }
 }
@@ -498,11 +512,11 @@ QString Base::pdftoxml (const QString& inFile, QVariant pagenums, const QString&
 		assert(pdf);
 		guiPrintDbg (debug::DBG_DBG,"Document opened.");
 	
-	}catch (PdfOpenException& e) 
+	}catch (PdfOpenException& e)
 	{
 		std::string err;
 		e.getMessage(err);
-		guiPrintDbg(debug::DBG_DBG,"Failed opeining document " << err);
+		guiPrintDbg(debug::DBG_DBG,"Failed opening document " << err);
 		return QString ();
 	}
 
@@ -540,7 +554,7 @@ QString Base::pdftoxml (const QString& inFile, QVariant pagenums, const QString&
 /**
  Return last error message from some operations (like load, save, etc ...)
  If last command was successfull, it is undefined what this function returns
- @return Last error message 
+ @return Last error message
  */
 QString Base::error() {
  return lastErrorMessage;
@@ -673,7 +687,7 @@ QString Base::tr(const QString &text,const QString &context/*=QString::null*/) {
 
 /**
  Call after some action causes changes in the treeview that cannot be handled by observers.
- This will cause tree to be reloaded after the script finishes. 
+ This will cause tree to be reloaded after the script finishes.
 */
 void Base::treeNeedReload() {
  treeReloadFlag=true;
@@ -681,7 +695,8 @@ void Base::treeNeedReload() {
 
 /** Convert string as it is read by QFile/QSFile/File in QSA to
  Unicode, asuming the string was utf8
- @param original 
+ @param original Original string
+ @return converted string
  */
 QString Base::utf8(QString original) {
  return QString::fromUtf8(original.latin1());
@@ -694,8 +709,8 @@ QStringList Base::variables() {
  return objs;
 }
 
-/** Return version of editor
- @return Version of editor (major.minor.release) */
+/** Return version of editor as string
+ @return Version of editor (major.minor.release or major.minor.relase-suffix) */
 QString Base::version() {
  return VERSION;
 }
