@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  "Merge documents pages" dialog<br>
  This dialog is used to select another PDF document and
@@ -22,7 +36,7 @@
 #include <qframe.h>
 #include QLISTBOX
 #include <qlayout.h>
-#include <cpdf.h>
+#include <kernel/cpdf.h>
 
 namespace gui {
 
@@ -109,7 +123,7 @@ void MergeDialog::mergeList_currentChanged( Q_ListBoxItem * item)
                 return;
 
         // enables to manipulate only with FROMFILE nodes
-        // original items has to be in same order as in 
+        // original items has to be in same order as in
         // creation time
         if(listItem->isType(NodeData::FROMFILE)) {
                 removeBtn->setEnabled(TRUE);
@@ -118,9 +132,9 @@ void MergeDialog::mergeList_currentChanged( Q_ListBoxItem * item)
                 // item
                 if(mergeList->currentItem()>0)
                         upBtn->setEnabled(TRUE);
-                else 
+                else
                         upBtn->setEnabled(FALSE);
-                
+
                 // down button is enabled only if we are not on last
                 // item
                 if(mergeList->currentItem() + 1>=(int)(mergeList->count())) downBtn->setEnabled(FALSE);
@@ -149,7 +163,7 @@ void MergeDialog::addBtn_clicked()
                 // skips unselected items
                 if(!fileList->isSelected(i))
                         continue;
-                
+
                 ListItem * fileItem=dynamic_cast<ListItem *>(fileList->item(i));
                 if(!fileItem)
                         continue;
@@ -183,7 +197,7 @@ void MergeDialog::addBtn_clicked()
                 addBtn->setEnabled(FALSE);
                 return;
         }
-        
+
         // select and mark as current element behind last added
         // to mergeList
         if(oldPos>=0)
@@ -270,7 +284,7 @@ void MergeDialog::openBtn_clicked() {
         initFileList(fileName);
         // TODO handle when file doesn't exist or error occured
         // during CPdf creation
-        
+
         // Open dialog causes disabling fileNameInput and fileNameBtn
         // and enabling merging stuff
         openBtn->setEnabled(FALSE);
@@ -308,14 +322,14 @@ MergeArray<int> * MergeDialog::getResult()
                         continue;
                 }
                 pages[length]=item->getNodeData()->position;
-                positions[length]=storePos; 
+                positions[length]=storePos;
                 ++length;
         }
 
         MergeArray<int> * mergeArray=new MergeArray<int>(length);
         mergeArray->initItems(pages);
         mergeArray->initPositions(positions);
-        
+
         return mergeArray;
 }
 
@@ -383,11 +397,11 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
 {
     if ( !name )
 	setName( "MergeDialog" );
-    MergeDialogLayout = new QGridLayout( this, 1, 1, 11, 6, "MergeDialogLayout"); 
+    MergeDialogLayout = new QGridLayout( this, 1, 1, 11, 6, "MergeDialogLayout");
 
-    layout48 = new QVBoxLayout( 0, 0, 6, "layout48"); 
+    layout48 = new QVBoxLayout( 0, 0, 6, "layout48");
 
-    layout27 = new QHBoxLayout( 0, 0, 6, "layout27"); 
+    layout27 = new QHBoxLayout( 0, 0, 6, "layout27");
 
     textLabel1 = new QLabel( this, "textLabel1" );
     textLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
@@ -403,7 +417,7 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
     layout27->addWidget( fileNameBtn );
     layout48->addLayout( layout27 );
 
-    layout2 = new QHBoxLayout( 0, 0, 6, "layout2"); 
+    layout2 = new QHBoxLayout( 0, 0, 6, "layout2");
     spacer1 = new QSpacerItem( 131, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
     layout2->addItem( spacer1 );
 
@@ -420,13 +434,13 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
     line1->setFrameShape( QFrame::HLine );
     layout48->addWidget( line1 );
 
-    layout47 = new QHBoxLayout( 0, 0, 6, "layout47"); 
+    layout47 = new QHBoxLayout( 0, 0, 6, "layout47");
 
     mergeList = new Q_ListBox( this, "mergeList" );
     mergeList->setEnabled( FALSE );
     layout47->addWidget( mergeList );
 
-    layout4 = new QVBoxLayout( 0, 0, 6, "layout4"); 
+    layout4 = new QVBoxLayout( 0, 0, 6, "layout4");
 
     addBtn = new QPushButton( this, "addBtn" );
     addBtn->setEnabled( FALSE );
@@ -454,7 +468,7 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
     layout47->addWidget( fileList );
     layout48->addLayout( layout47 );
 
-    layout6 = new QHBoxLayout( 0, 0, 5, "layout6"); 
+    layout6 = new QHBoxLayout( 0, 0, 5, "layout6");
 
     spacer5 = new QSpacerItem( 61, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
     layout6->addItem( spacer5 );
