@@ -1,12 +1,28 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
+#include "pagespace.h"
+#include QSCROLLVIEW
 #include <stdlib.h>
 #include <math.h>
 
@@ -18,16 +34,19 @@
 //#include <qdockarea.h>
 #include <qfiledialog.h>
 #include <qmessagebox.h>
+#include QSTRLIST
 
-#include "pagespace.h"
 #include "settings.h"
-#include "cpdf.h"
-#include "cpage.h"
-#include "static.h"
+#include "kernel/cpdf.h"
+#include "kernel/cpage.h"
+#include "kernel/static.h"
 #include "rect2Darray.h"
 
 #include "pageviewmode.h"
 #include "units.h"
+#ifdef QT4
+#include <QImageWriter>
+#endif
 
 /** Helpes struct for initializing width and height text labeles. */
 typedef struct { /** lebel width */ int labelWidth, /** label height */ labelHeight; } initStruct;
@@ -129,7 +148,7 @@ PageSpace::PageSpace(QWidget *parent /*=0*/, const char *name /*=0*/) : QWidget(
 	pageNumber->setAlignment( Qt::AlignCenter | pageNumber->alignment() );
 	hBox->addWidget( pageNumber );
 	hBox->addStretch();
-        
+
  	actualUnits.setDefaultUnits( globalSettings->read( PAGESPC + VIEWED_UNITS, DEFAULT__VIEWED_UNITS ) );
 
 	Init( &is , format + "00000000xx" );
@@ -148,7 +167,7 @@ PageSpace::PageSpace(QWidget *parent /*=0*/, const char *name /*=0*/) : QWidget(
 	textLine->hide();
 
 	// if something use on page, take focus
-	setFocusPolicy( QWidget::WheelFocus );
+	setFocusPolicy( TheWheelFocus );
 }
 
 PageSpace::~PageSpace() {
@@ -305,12 +324,12 @@ int PageSpace::getResizingZone() {
 	// else
 	return globalSettings->readNum( PAGESPC + RESIZINGZONE, DEFAULT__RESIZINGZONE );
 }
-void PageSpace::setSelectionMode( QString mode, 
+void PageSpace::setSelectionMode( QString mode,
 									QString drawingObject,
 									QString scriptFncAtMouseRelease,
 									QString scriptFncAtMoveSelectedObjects,
 									QString scriptFncAtResizeSelectedObjects ) {
-	selectionMode.reset( 
+	selectionMode.reset(
 					PageViewModeFactory::create( mode,
 												drawingObject,
 												scriptFncAtMouseRelease,
@@ -358,10 +377,16 @@ bool PageSpace::isSomeoneSelected ( ) {
 
 bool PageSpace::saveImageWithDialog ( bool onlySelectedArea ) {
 	QString filters = "";
-	for (unsigned int i = 0; i < QImageIO::outputFormats().count() ;++i) {
+
+#ifdef QT4
+	QStrList lst=QImageWriter::supportedImageFormats();
+#else
+	QStrList lst=QImageIO::outputFormats();
+#endif
+	for (unsigned int i = 0; i < lst.count() ;++i) {
 		filters += QString("\n%1 (*.%2)")
-				.arg(QImageIO::outputFormats().at(i))
-				.arg(QString(QImageIO::outputFormats().at(i)).lower());
+				.arg(QString(lst.at(i)))
+				.arg(QString(lst.at(i)).lower());
 	}
 
 	QString sf;
@@ -370,7 +395,7 @@ bool PageSpace::saveImageWithDialog ( bool onlySelectedArea ) {
 
 	QFile f ( filename );
 	if ( (! filename.isNull()) &&
-		((! f.exists()) || 
+		((! f.exists()) ||
 			(0 == QMessageBox::question( this, QObject::tr("Overwrite?"),
                                                         QObject::tr("File called \"%1\" already exists. Do you want to overwrite it?").arg( filename ),
 							QObject::tr("&Yes"), QObject::tr("&No"),
@@ -399,11 +424,11 @@ int PageSpace::findText ( QString &text, bool startAtTop, double xStart, double
 	tsp.xEnd = xEnd;
 	tsp.yEnd = yEnd;
 
-	std::vector<Rectangle> recs;
-	int count = actualPage->findText( text, recs, tsp );
+	std::vector<libs::Rectangle> recs;
+	int count = actualPage->findText( util::convertFromUnicode(text,util::PDF), recs, tsp );
 
 	guiPrintDbg( debug::DBG_DBG, "Founded "<<count<<" items:");
-	for (std::vector<Rectangle>::iterator it = recs.begin(); it != recs.end() ; ++it) {
+	for (std::vector<libs::Rectangle>::iterator it = recs.begin(); it != recs.end() ; ++it) {
 		guiPrintDbg( debug::DBG_DBG, "   ("<<(*it)<<")");
 	}
 
@@ -424,7 +449,7 @@ int PageSpace::findText ( QString &text, bool startAtTop, double xStart, double
 		for ( ; !it.isEnd() ; it.next() ) {
 			boost::shared_ptr<PdfOperator> h_textOp ( it.getCurrent() );
 
-			Rectangle bbox = h_textOp->getBBox();
+			libs::Rectangle bbox = h_textOp->getBBox();
 			if (bbox.xleft > bbox.xright) {
 				double h = bbox.xleft;
 				bbox.xleft = bbox.xright;
@@ -442,7 +467,7 @@ int PageSpace::findText ( QString &text, bool startAtTop, double xStart, double
 			bbox.yright -= bbox.yright / 1e10;
 
 			// loop through bboxes of founded text
-			for ( std::vector<Rectangle>::iterator it_recs = recs.begin(); it_recs != recs.end() ; ++it_recs ) {
+			for ( std::vector<libs::Rectangle>::iterator it_recs = recs.begin(); it_recs != recs.end() ; ++it_recs ) {
 				if ((	( std::min( (*it_recs).xleft, (*it_recs).xright ) <= bbox.xleft ) &&	// if operators width is all inside founded area
 						( std::max( (*it_recs).xleft, (*it_recs).xright ) >= bbox.xright ) &&
 						(std::max( std::min( (*it_recs).yleft, (*it_recs).yright ) , bbox.yleft ) <=	// and has some height intersection
