@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 #include "pageviewS.h"
 
 #include <stdlib.h>
@@ -14,10 +28,10 @@
 #include <assert.h>
 
 #include "util.h"
-#include "debug.h"
-#include "pdfoperators.h"
+#include "utils/debug.h"
+#include "kernel/pdfoperators.h"
 
-#include "OutputDev.h"
+#include "xpdf/OutputDev.h"
 #include "QOutputDevPixmap.h"
 
 #include "rect2Darray.h"
@@ -107,7 +121,7 @@ void PageViewS::updateDisplayParameters ( OutputDev & output ) {
 
 	// update mediabox
 	try {
-		Rectangle mb = actualPage->getMediabox();
+		libs::Rectangle mb = actualPage->getMediabox();
 		displayParams.pageRect = mb;
 	} catch (ElementNotFoundException) {
 		// TODO find mediabox in parent
