@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 // vim:tabstop=4:shiftwidth=4:noexpandtab
 #ifndef __PAGEVIEWMODE_H__
 #define __PAGEVIEWMODE_H__
@@ -21,10 +35,10 @@
 /*class pdfobjects::CAnnotation;
 class pdfobjects::CPage;
 class pdfobjects::PdfOperator;*/
-#include "cpage.h"
-#include "cannotation.h"
-#include "pdfoperators.h"
-#include "static.h"
+#include "kernel/cpage.h"
+#include "kernel/cannotation.h"
+#include "kernel/pdfoperators.h"
+#include "kernel/static.h"
 
 using namespace pdfobjects;
 
@@ -297,8 +311,8 @@ class PageViewMode: public QObject {
 			 */
 			virtual void resizedSelectedObjects ( QMouseEvent * e, QPainter * p, QWidget * w );
 
-			/* ------------------------------------------------------------------------------ * 
-			 * --- mouse press (and coresponding release) events not above selection area --- * 
+			/* ------------------------------------------------------------------------------ *
+			 * --- mouse press (and coresponding release) events not above selection area --- *
 			 * ------------------------------------------------------------------------------ */
 
 			/** Method is calling if is press left mouse button.
@@ -386,8 +400,8 @@ class PageViewMode: public QObject {
 			 */
 			virtual void mouseMoveWithPressedLeftButton ( QMouseEvent * e, QPainter * p, QWidget * w );
 
-			/* ------------------------------------------------------------------------------ * 
-			 * ---        mouse events - equivalents of method called in QWidget          --- * 
+			/* ------------------------------------------------------------------------------ *
+			 * ---        mouse events - equivalents of method called in QWidget          --- *
 			 * ------------------------------------------------------------------------------ */
 
 			/** Method is call if press mouse button (see Qt::QWidget::mousePressEvent)
@@ -456,8 +470,8 @@ class PageViewMode: public QObject {
 			 */
 			virtual void wheelEvent ( QWheelEvent * e, QPainter * p, QWidget * w );
 
-			/* ------------------------------------------------------------------------------ * 
-			 * ---         key events - equivalents of method called in QWidget           --- * 
+			/* ------------------------------------------------------------------------------ *
+			 * ---         key events - equivalents of method called in QWidget           --- *
 			 * ------------------------------------------------------------------------------ */
 
 			/** Method is call if press key event (see Qt::QWidget::keyPressEvent)
@@ -479,8 +493,8 @@ class PageViewMode: public QObject {
 			 */
 			virtual void keyReleaseEvent ( QKeyEvent * e, QPainter * p, QWidget * w );
 
-			/* ------------------------------------------------------------------------------ * 
-			 * ---        focus events - equivalents of method called in QWidget          --- * 
+			/* ------------------------------------------------------------------------------ *
+			 * ---        focus events - equivalents of method called in QWidget          --- *
 			 * ------------------------------------------------------------------------------ */
 
 			/** Method is call if focus-in event (see Qt::QWidget::focusInEvent)
@@ -549,7 +563,7 @@ class PageViewMode: public QObject {
 
 			/** Extra initialization mode.
 			 * @param page			Page which are viewed.
-			 * @param displayParams	Display parameters viewed page. 
+			 * @param displayParams	Display parameters viewed page.
 			 *
 			 * This method is good called after change viewed page, or change display parameters (zoom, rotation, ...)
 			 * Is good for initialize other objects then operators (E.g. for annotation).
@@ -609,7 +623,7 @@ class PageViewMode: public QObject {
 			/** Method for calculation resizing mode
 			 * @param r rectsngle for resizing
 			 * @param p cursor position
-			 * 
+			 *
 			 * @return combination of enum resizingParts
 			 */
 			virtual int	theNeerestResizingMode ( const QRegion & r, const QPoint & p );
@@ -687,7 +701,7 @@ class PageViewMode: public QObject {
 			 * 		%4	will be replaced with global position of y2 (global Y position at mouse release)
 			 *
 			 * @see QString::arg
-			 * 
+			 *
 			 * Function in script:
 			 * 			fncName ( x1:Number, y1:Number, x2:Number, y2:Number )  { ... }
 			 */
@@ -700,7 +714,7 @@ class PageViewMode: public QObject {
 			 * 		%2	will be replaced with dy
 			 *
 			 * @see QString::arg
-			 * 
+			 *
 			 * Function in script:
 			 * 			fncName ( dx:Number, dy:Number )  { ... }
 			 */
@@ -715,7 +729,7 @@ class PageViewMode: public QObject {
 			 * 		%4	will be replaced with dbottom
 			 *
 			 * @see QString::arg
-			 * 
+			 *
 			 * Function in script:
 			 * 			fncName ( dleft:Number, dtop:Number, dright:Number, dbottom:Number )  { ... }
 			 *
@@ -885,7 +899,7 @@ class PageViewMode_TextSelection: public PageViewMode {
 			 * @param last	Last selected operator (pointer to sorted structure by line and word on line)
 			 * @param selOpsRegion	Bounding region of all selected operators.
 			 * @param selOps		Vector of selected operators.
-			 * 
+			 *
 			 * Method find the nearest text operator to mouse cursor and select all text operator from first selected
 			 * text operator to it respecting word and line order.
 			 * New selected operators add to \a selOps. Removed selected operators remove from that.
@@ -1124,7 +1138,7 @@ class PageViewMode_Annotations: public PageViewMode {
 			virtual void actualizeSelection ();
 			/** Extra initialization mode.
 			 * @param page			Page which are viewed.
-			 * @param displayParams	Display parameters viewed page. 
+			 * @param displayParams	Display parameters viewed page.
 			 *
 			 * This method is good called after change viewed page, or change display parameters (zoom, rotation, ...)
 			 * Initialize annotation for selecting on the page \a page.
@@ -1164,7 +1178,7 @@ class PageViewMode_Annotations: public PageViewMode {
 			 *
 			 * @return Return activation rectangle for \a annot.
 			 */
-			Rectangle getRectOfAnnotation ( boost::shared_ptr<CAnnotation> & annot );
+			libs::Rectangle getRectOfAnnotation ( boost::shared_ptr<CAnnotation> & annot );
 			/** Get struct for annotation and its activation rectangle for annotation under point on the page
 			 * @param p	Position on the page.
 			 *
