@@ -1,10 +1,24 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko,
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
  *                                              Miroslav Jahoda,
  *                                              Jozef Misutka,
  *                                              Martin Petricek
  *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
  * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
 /** @file
@@ -12,7 +26,7 @@
 */
 #include "pdfeditwindow.h"
 #include "qtcompat.h"
-#include "GlobalParams.h"
+#include "xpdf/GlobalParams.h"
 #include "additemdialog.h"
 #include "basegui.h"
 #include "commandwindow.h"
@@ -662,7 +676,6 @@ bool PdfEditWindow::save(bool newRevision/*=false*/) {
  base->setError("");//No error
  if (!document) {
   base->setError(tr("No document to save"));
-  base->print(base->error());
   return false;
  }
  if (fileName.isNull()) { //We need a name
@@ -680,6 +693,9 @@ bool PdfEditWindow::save(bool newRevision/*=false*/) {
   } catch (ReadOnlyDocumentException &e) {
    base->setError(tr("Document is in read-only mode"));
    return false;
+  } catch (NotImplementedException &e) {
+   base->setError(tr("Saving not implemented:\n%1").arg(e.what()));
+   return false;
   } catch (...) {
    base->setError(tr("Unknown error occured while saving document"));
    return false;
@@ -725,12 +741,12 @@ bool PdfEditWindow::saveCopy(const QString &name) {
  base->setError("");//No error
  if (!document) {
   base->setError(tr("No document to save"));
-  base->print(base->error());
   return false;
  }
- bool res=util::saveCopy(document,name);
+ QString errorString;
+ bool res=util::saveCopy(document,name,&errorString);
  if (!res) {
-  base->setError(tr("Error occured while saving copy"));
+  base->setError(tr("Error occured while saving copy:\n%1").arg(errorString));
  }
  return res;
 }
@@ -808,7 +824,7 @@ bool PdfEditWindow::openFile(const QString &name) {
   // this will cause displaying of content saving progress
   pdfobjects::utils::IPdfWriter * writer=document->getPdfWriter();
   if(writer) {
-   writer->registerObserver(progressObserver);
+   REGISTER_PTR_OBSERVER(writer, progressObserver);
   }
   assert(document);
   guiPrintDbg(debug::DBG_DBG,"Opened document");
