@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  PropertyEditor - widget for editing properties of selected object
  Can edit Dict and Array containing primitive types and also primitive type as one items itself
@@ -17,7 +31,7 @@
 #include "propertyeditor.h"
 #include <utils/debug.h>
 #include "util.h"
-#include <cobject.h>
+#include <kernel/cobject.h>
 #include <qapplication.h>
 #include "main.h"
 #include "propertyfactory.h"
@@ -293,7 +307,7 @@ void PropertyEditor::setObject(boost::shared_ptr<IProperty> pdfObject) {
   }
   grid->update();
  } else if (pdfObject->getType()==pStream) {	//Object is CCtream -> edit its properties.
-  //Basically the same as CDict  .... 
+  //Basically the same as CDict  ....
   CStream *cstream=dynamic_cast<CStream*>(pdfObject.get());
   vector<string> list;
   cstream->getAllPropertyNames(list);
@@ -425,7 +439,7 @@ void PropertyEditor::commitProperty() {
  }
 }
 
-/** 
+/**
  Receive and resend informational text
  @param message Message
 */
@@ -433,7 +447,7 @@ void PropertyEditor::receiveInfoText(const QString &message) {
  emit infoText(message);
 }
 
-/** 
+/**
  Receive and resend warning message
  @param message Message
 */
