@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  QObject wrapper around CPage (Page in document)<br>
  Export some functions to scripting.<br>
@@ -22,16 +36,13 @@
 #include "qsannotation.h"
 #include "qspdfoperatorstack.h"
 #include "util.h"
-#include <cpage.h>
+#include <kernel/cpage.h>
 
 namespace gui {
 
 using namespace std;
 using namespace util;
 
-/** List of fonts returned ftom CPage::getFontIdsAndNames */
-typedef vector<pair<string,string> > FontList;
-
 /**
  Construct wrapper with given CPage
  @param _page CPage shared pointer
@@ -60,7 +71,7 @@ QSDict* QSPage::getDictionary() {
  return new QSDict(obj->getDictionary(),base);
 }
 
-/** 
+/**
  \see CPage::moveAbove
  @param cs Content stream to move one level up painting order
 */
@@ -79,7 +90,7 @@ void QSPage::moveAbove(QSContentStream* cs) {
 }
 
 
-/** 
+/**
  \see CPage::moveBelow
  @param cs Content stream to move one level below in painting order
 */
@@ -97,7 +108,7 @@ void QSPage::moveBelow(QSContentStream* cs) {
  }
 }
 
-/** 
+/**
  \see CPage::moveAbove
  @param cs Content stream to move one level up painting order
 */
@@ -107,7 +118,7 @@ void QSPage::moveAbove(QObject* cs) {
  moveAbove(qsc);
 }
 
-/** 
+/**
  \see CPage::moveBelow
  @param cs Content stream to move one level up painting order
 */
@@ -117,7 +128,7 @@ void QSPage::moveBelow(QObject* cs) {
  moveBelow(qsc);
 }
 
-/** 
+/**
  \see CPage::moveAbove
  @param csi Index of content stream to move one level up painting order
 */
@@ -135,7 +146,7 @@ void QSPage::moveAbove(int csi) {
  }
 }
 
-/** 
+/**
  \see CPage::moveBelow
  @param csi Index of content stream to move one level below in painting order
 */
@@ -176,7 +187,7 @@ void QSPage::setTransformMatrix(QVariant tMatrix) {
  }
 }
 
-/** 
+/**
  Add content stream to page, created from new operator stack
  Content stream is prepended before other content streams
  \see CPage::addContentStreamToFront
@@ -191,7 +202,7 @@ void QSPage::prependContentStream(QSPdfOperatorStack* opStack) {
  }
 }
 
-/** 
+/**
  Add content stream to page, created from new operator stack
  Content stream in appended after other content streams
  \see CPage::addContentStreamToBack
@@ -290,7 +301,7 @@ int QSPage::getChangeCount() {
 void QSPage::loadContentStreams() {
  obj->getContentStreams(streams);
  //Store number of streams
- numStreams=streams.size(); 
+ numStreams=streams.size();
 }
 
 //TODO: get list of annotations
@@ -319,7 +330,7 @@ void QSPage::addAnnotation(QObject *an) {
  \see CPage::getMediabox
 */
 QVariant QSPage::mediabox() {
- Rectangle r=obj->getMediabox();
+ libs::Rectangle r=obj->getMediabox();
  Q_List<QVariant> rect;
  rect.append(r.xleft);
  rect.append(r.yleft);
@@ -337,7 +348,7 @@ QVariant QSPage::mediabox() {
  @param y2 Y coordinate of lower right media box corner
 */
 void QSPage::setMediabox(double x1,double y1,double x2,double y2) {
- Rectangle r(x1,y1,x2,y2);
+ libs::Rectangle r(x1,y1,x2,y2);
  try {
   obj->setMediabox(r);
  } catch (ReadOnlyDocumentException &e) {
@@ -353,7 +364,7 @@ void QSPage::setMediabox(double x1,double y1,double x2,double y2) {
 void QSPage::setMediabox(QRect rc) {
  //Note that Rectangle uses double coordinates, while Qrect use int coordinates.
  //However, media box is often array of int, so this may not be a problem
- Rectangle r(rc.left(),rc.top(),rc.right(),rc.bottom());
+ libs::Rectangle r(rc.left(),rc.top(),rc.right(),rc.bottom());
  try {
   obj->setMediabox(r);
  } catch (ReadOnlyDocumentException &e) {
@@ -368,11 +379,11 @@ void QSPage::setMediabox(QRect rc) {
  @return list of font id's and names
 */
 QStringList QSPage::getFontIdsAndNames(bool onlyNames/*=false*/) {
- FontList fonts;
+ CPage::FontList fonts;
  //Format is like "pair<R13, Helvetica>"
  obj->getFontIdsAndNames(fonts);
  QStringList ret;
- FontList::iterator it;
+ CPage::FontList::iterator it;
  for( it=fonts.begin();it!=fonts.end();++it) { // for each font
   if (!onlyNames) ret+=convertToUnicode(it->first,PDF);
   ret+=convertToUnicode(it->second,PDF);
@@ -387,11 +398,11 @@ QStringList QSPage::getFontIdsAndNames(bool onlyNames/*=false*/) {
  @return ID of font with given name, or NULL if not found in the page
 */
 QString QSPage::getFontId(const QString &fontName) {
- FontList fonts;
+ CPage::FontList fonts;
  //Format is like "pair<R13, Helvetica>"
  obj->getFontIdsAndNames(fonts);
  QStringList ret;
- FontList::iterator it;
+ CPage::FontList::iterator it;
  string fontNameString=convertFromUnicode(fontName,PDF);
  for( it=fonts.begin();it!=fonts.end();++it) { // for each font
   if (it->second==fontNameString) return convertToUnicode(it->first,PDF);
