@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  RefProperty - class for widget containing one editable property of type "Ref"<br>
  Represented by editable line and button allowing to pick reference target from the list<br>
@@ -19,7 +33,7 @@
 #include "refpropertydialog.h"
 #include "refvalidator.h"
 #include "util.h"
-#include <cobject.h>
+#include <kernel/cobject.h>
 #include <qcolor.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
@@ -139,7 +153,7 @@ void RefProperty::setValue(IProperty *pdfObject) {
  }
  if (pdf) {
   //We can check for validity
-  if (!isRefValid(pdf,val)) { 
+  if (!isRefValid(pdf,val)) {
    emit warnText("Reference is not valid!");
    ed->setFocus();
    return; //not valid
