@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  TreeItem - class holding one PDF object (IProperty) in tree, descendant of TreeItemAbstract
  @author Martin Petricek
@@ -26,7 +40,7 @@
 #include "pdfutil.h"
 #include "util.h"
 #include "qsiproperty.h"
-#include <cobject.h>
+#include <kernel/cobject.h>
 
 namespace gui {
 
@@ -136,7 +150,7 @@ boost::shared_ptr<IProperty> TreeItem::getObject() {
  return obj;
 }
 
-/** 
+/**
  This method is needed for "deep reload" to work
  Try to replace object inside this treeitem with a new one.
  @param newItem new object to replace the old one
@@ -182,13 +196,13 @@ bool TreeItem::haveObserver() {
 void TreeItem::initObserver() {
  guiPrintDbg(debug::DBG_DBG,"Set Observer");
  observer=boost::shared_ptr<TreeItemObserver>(new TreeItemObserver(this));
- obj->registerObserver(observer);
+ REGISTER_SHAREDPTR_OBSERVER(obj, observer);
 }
 
 /** Unsets observer for this item */
 void TreeItem::uninitObserver() {
  observer->deactivate();
- obj->unregisterObserver(observer);
+ UNREGISTER_SHAREDPTR_OBSERVER(obj, observer);
  observer.reset();
  guiPrintDbg(debug::DBG_DBG,"UnSet Observer");
 }
