@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  TreeItemAnnotation - class holding one annotation in tree
  @author Martin Petricek
@@ -19,8 +33,8 @@
 #include "util.h"
 #include "pdfutil.h"
 #include "qsannotation.h"
-#include <cannotation.h>
-#include <cpage.h>
+#include <kernel/cannotation.h>
+#include <kernel/cpage.h>
 
 namespace gui {
 
@@ -124,7 +138,7 @@ QSCObject* TreeItemAnnotation::getQSObject() {
 
 //See TreeItemAbstract for description of this virtual method
 void TreeItemAnnotation::remove() {
- //Remove from CPage 
+ //Remove from CPage
  page->delAnnotation(obj);
  return;
 }
