@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  TreeItemPage - class holding CPage in tree, descendant of TreeItemAbstract
  @author Martin Petricek
@@ -21,10 +35,10 @@
 #include "treeitemdict.h"
 #include "treeitempageobserver.h"
 #include "util.h"
-#include <cannotation.h>
-#include <cobject.h>
-#include <cpage.h>
-#include <cpdf.h>
+#include <kernel/cannotation.h>
+#include <kernel/cobject.h>
+#include <kernel/cpage.h>
+#include <kernel/cpdf.h>
 #include <qobject.h>
 
 namespace gui {
@@ -77,13 +91,13 @@ void TreeItemPage::init(boost::shared_ptr<CPage> page,const QString &name) {
 void TreeItemPage::initObserver() {
  guiPrintDbg(debug::DBG_DBG,"Set Observer");
  observer=boost::shared_ptr<TreeItemPageObserver>(new TreeItemPageObserver(this));
- obj->registerObserver(observer);
+ REGISTER_SHAREDPTR_OBSERVER(obj, observer);
 }
 
 /** Unsets observer for this item */
 void TreeItemPage::uninitObserver() {
  observer->deactivate();
- obj->unregisterObserver(observer);
+ UNREGISTER_SHAREDPTR_OBSERVER(obj, observer);
  observer.reset();
  guiPrintDbg(debug::DBG_DBG,"UnSet Observer");
 }
@@ -96,7 +110,7 @@ boost::shared_ptr<CPage> TreeItemPage::getObject() {
  return obj;
 }
 
-/** 
+/**
  This method is needed for "deep reload" to work
  Try to replace page inside this treeitem with a new one.
  @param newPage new page to replace the old one
@@ -164,13 +178,13 @@ bool TreeItemPage::validChild(const QString &name,Q_ListViewItem *oldChild) {
  TreeItemContentStream *its=dynamic_cast<TreeItemContentStream*>(oldChild);
  if (its && name[0]=='s') { //Is a content stream
   size_t streamNumber=name.mid(1).toUInt();
-  assert(streamNumber<streams.size());  //These should be already weed out ... 
+  assert(streamNumber<streams.size());  //These should be already weed out ...
   return streams[streamNumber].get()==its->getObject().get();
  }
  TreeItemAnnotation *ita=dynamic_cast<TreeItemAnnotation*>(oldChild);
  if (ita && name[0]=='a') { //Is an annotation
   size_t annotNumber=name.mid(1).toUInt();
-  assert(annotNumber<anots.size());  //These should be already weed out ... 
+  assert(annotNumber<anots.size());  //These should be already weed out ...
   return anots[annotNumber].get()==ita->getObject().get();
  }
  //Something else
