@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  TreeItemPdfOperator - class holding one PDF Operator in tree, descendant of TreeItem
  @author Martin Petricek
@@ -19,9 +33,9 @@
 #include "treeitem.h"
 #include "treeitempdfoperator.h"
 #include "util.h"
-#include <cobject.h>
-#include <ccontentstream.h>
-#include <pdfoperators.h>
+#include <kernel/cobject.h>
+#include <kernel/ccontentstream.h>
+#include <kernel/pdfoperators.h>
 
 namespace gui {
 
@@ -78,7 +92,7 @@ TreeItemPdfOperator::TreeItemPdfOperator(TreeData *_data,Q_ListViewItem *parent,
 
 /**
  Return hint (description) of this item.
- Hint is taken from OperatorHint class 
+ Hint is taken from OperatorHint class
  @return hint for given item
 */
 QString TreeItemPdfOperator::itemHint() {
@@ -99,7 +113,7 @@ TreeItemAbstract* TreeItemPdfOperator::createChild(const QString &name,__attribu
   guiPrintDbg(debug::DBG_DBG,"Position mod " << position);
   assert(params[position].get());
   QString xName=QObject::tr("Parameter")+" "+QString::number(position);
-  return TreeItem::create(data,this,params[position],xName,after); 
+  return TreeItem::create(data,this,params[position],xName,after);
  }
 }
 
