@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  TreeWindow - class providing treeview of PDF objects
  @author Martin Petricek
@@ -27,8 +41,8 @@
 #include "treeitemoperatorcontainer.h"
 #include "treeitem.h"
 #include "base.h"
-#include <ccontentstream.h>
-#include <cpdf.h>
+#include <kernel/ccontentstream.h>
+#include <kernel/cpdf.h>
 #include <utils/debug.h>
 
 namespace gui {
@@ -183,7 +197,7 @@ void TreeWindow::paintEvent(QPaintEvent *e) {
 }
 
 /**
- Called when any settings are updated (in script, option editor, etc ...) 
+ Called when any settings are updated (in script, option editor, etc ...)
  @param key Key of setting which have changed
 */
 void TreeWindow::settingUpdate(QString key) {
@@ -213,7 +227,7 @@ void TreeWindow::treeSelectionChanged() {
  emit itemSelected();
 }
 
-/** 
+/**
  Return QSCObject from currently selected item
  Caller is responsible for freeing object
  @return QSCObject from current item
@@ -225,7 +239,7 @@ QSCObject* TreeWindow::getSelected() {
  return selected->getQSObject();
 }
 
-/** 
+/**
  Return QSCObject from next selected item
  Caller is responsible for freeing object
  @return QSCObject from next item
@@ -237,7 +251,7 @@ QSCObject* TreeWindow::nextSelected() {
  return selected->getQSObject();
 }
 
-/** 
+/**
  Return pointer to currently selected tree item (single select)
  or first selected tree item (multiselect)
  @return currently selected item
@@ -257,7 +271,7 @@ TreeItemAbstract* TreeWindow::getSelectedItem() {
  }
 }
 
-/** 
+/**
  Return pointer to next selected tree item in multiselect mode
  (next mean next from the last item returned by getSelectedItem or nextSelectedItem)
  Returns NULL if nor more selected items can be found.
@@ -296,7 +310,7 @@ void TreeWindow::init(pdfobjects::CPdf *pdfDoc,const QString &fileName) {
  clear();
  rootName=fileName;
  setUpdatesEnabled( FALSE );
- TreeItemAbstract *rootItem=new TreeItemPdf(data,pdfDoc,tree,fileName); 
+ TreeItemAbstract *rootItem=new TreeItemPdf(data,pdfDoc,tree,fileName);
  rootItem->setOpen(TRUE);
  setUpdatesEnabled( TRUE );
 }
@@ -310,14 +324,14 @@ void TreeWindow::init(boost::shared_ptr<pdfobjects::IProperty> doc,const QString
  clear();
  if (doc.get()) {
   setUpdatesEnabled( FALSE );
-  TreeItemAbstract *rootItem=TreeItem::create(data,tree,doc,pName); 
+  TreeItemAbstract *rootItem=TreeItem::create(data,tree,doc,pName);
   rootItem->setOpen(TRUE);
   setUpdatesEnabled( TRUE );
  }
 }
 
 /**
- Init contents of treeview from given Content Stream 
+ Init contents of treeview from given Content Stream
  @param cs Content Stream used to initialize treeview
  @param pName Name of the content stream passed
 */
@@ -325,7 +339,7 @@ void TreeWindow::init(boost::shared_ptr<pdfobjects::CContentStream> cs,const QSt
  clear();
  if (cs.get()) {
   setUpdatesEnabled( FALSE );
-  TreeItemAbstract *rootItem=new TreeItemContentStream(data,tree,cs,pName); 
+  TreeItemAbstract *rootItem=new TreeItemContentStream(data,tree,cs,pName);
   rootItem->setOpen(TRUE);
   setUpdatesEnabled( TRUE );
  }
@@ -339,7 +353,7 @@ void TreeWindow::init(boost::shared_ptr<pdfobjects::CContentStream> cs,const QSt
 void TreeWindow::init(const OperatorVector &vec,const QString &pName/*=QString::null*/) {
  clear();
  setUpdatesEnabled( FALSE );
- TreeItemAbstract *rootItem=new TreeItemOperatorContainer(data,tree,vec,pName); 
+ TreeItemAbstract *rootItem=new TreeItemOperatorContainer(data,tree,vec,pName);
  rootItem->setOpen(TRUE);
  //Select all items except the root
  Q_ListViewItem *sel=rootItem->itemBelow();
@@ -359,7 +373,7 @@ void TreeWindow::init(const OperatorVector &vec,const QString &pName/*=QString::
 void TreeWindow::init(const AnnotationVector &vec,boost::shared_ptr<pdfobjects::CPage> page,const QString &pName/*=QString::null*/) {
  clear();
  setUpdatesEnabled( FALSE );
- TreeItemAbstract *rootItem=new TreeItemAnnotationContainer(data,tree,vec,page,pName); 
+ TreeItemAbstract *rootItem=new TreeItemAnnotationContainer(data,tree,vec,page,pName);
  rootItem->setOpen(TRUE);
  //Select all items except the root
  Q_ListViewItem *sel=rootItem->itemBelow();
