@@ -1,20 +1,34 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 #ifndef __TREEWINDOW_H__
 #define __TREEWINDOW_H__
 
 #include "qtcompat.h"
 #include QLISTVIEW
 #include <qwidget.h>
-#include <cobject.h>
-#include <cpage.h>
+#include <kernel/cobject.h>
+#include <kernel/cpage.h>
 #include "types.h"
 class Q_ListView;
 class QListViewItem;
@@ -84,7 +98,7 @@ protected:
 private slots:
  void moveOnItem(QListViewItem *item);
  void moveOffItem();
- void treeSelectionChanged(QListViewItem *item); 
+ void treeSelectionChanged(QListViewItem *item);
  void treeSelectionChanged();
  void mouseClicked(int button,QListViewItem* item,const QPoint &coord,int column);
  void mouseDoubleClicked(QListViewItem* item,const QPoint &coord,int column);
