@@ -1,25 +1,32 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
- *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
-// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 /*
- * =====================================================================================
- *        Filename:  carray.cc
- *         Created:  02/02/2006 
- *          Author:  jmisutka (06/01/19), 
- * 			
- * =====================================================================================
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
+// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 
-#include "static.h"
-#include "carray.h"
-#include "cpdf.h"
+#include "kernel/static.h"
+#include "kernel/carray.h"
+#include "kernel/cpdf.h"
+#include "kernel/factories.h"
 
 //=====================================================================================
 namespace pdfobjects {
@@ -319,18 +326,28 @@ CArray::setProperty (PropertyId id, IProperty& newIp)
 CArray::_makeXpdfObject () const
 {
 	//kernelPrintDbg (debug::DBG_DBG,"_makeXpdfObject");
-	
-	string rpr;
-	getStringRepresentation (rpr);
+	::Object * arrayObj = XPdfObjectFactory::getInstance();
 
-	::Object* o = NULL;
-	if (hasValidPdf (this))
-		o = utils::xpdfObjFromString (rpr, this->getPdf()->getCXref());
-	else
-		o = utils::xpdfObjFromString (rpr);
-	assert (o->isArray());
+	// We need to be carefull with pdf from property. Some
+	// properties (usually artificial ones) can be without
+	// any bound PDF instance. Nevertheless NULL xref is ok for
+	// Object hierarchy (see Object::fetch method)
+	XRef *xref = NULL;
+	CPdf *pdf = getPdf();
+	if(pdf)
+		xref = pdf->getCXref();
+	arrayObj->initArray(xref);
+	::Array * array = arrayObj->getArray();
 
-	return o;
+	Value::const_iterator it = value.begin();
+	for (; it != value.end(); ++it)
+	{
+		Object * propObj = (*it)->_makeXpdfObject();
+		array->add(propObj);
+		gfree(propObj);
+	}
+	assert(static_cast<unsigned int>(array->getLength()) == getPropertyCount());
+	return arrayObj;
 }
 
 
@@ -364,7 +381,7 @@ CArray::_objectChanged (boost::shared_ptr<IProperty> newValue, boost::shared_ptr
 // Set mode
 //
 void
-CArray::_setMode (boost::shared_ptr<IProperty> ip, PropertyId id) const
+CArray::_setMode (boost::shared_ptr<IProperty> ip, PropertyId /*id*/) const
 {
 	/* FIXME this is not good implementation because we don't have
 	 * information about array name here. So if it is direct child
