@@ -1,32 +1,39 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
- *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
-// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 /*
- * =====================================================================================
- *        Filename:  ccontentstream.cc
- *         Created:  03/24/2006 10:33:34 PM CET
- *          Author:  jmisutka, mjahoda
- * =====================================================================================
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
+// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 
 // static
-#include "static.h"
-#include "ccontentstream.h"
+#include "kernel/static.h"
+#include "kernel/ccontentstream.h"
 
 //
-#include "cpdf.h"
-#include "pdfoperators.h"
-#include "stateupdater.h"
-#include "cobject.h"
-#include "factories.h"
-#include "cinlineimage.h"
+#include "kernel/cpdf.h"
+#include "kernel/pdfoperators.h"
+#include "kernel/stateupdater.h"
+#include "kernel/cobject.h"
+#include "kernel/factories.h"
+#include "kernel/cinlineimage.h"
 
 //fabs
 #include <math.h>
@@ -71,37 +78,13 @@ namespace {
 		{
 			// Set cs
 			it.getCurrent()->setContentStream (cs);
-			
-			// Get operands
-			PdfOperator::Operands operands;
-			it.getCurrent()->getParameters (operands);
-			
+
 			//
 			// Set valid pdf and ref but lock the change 
 			// 	-- cstream won't get notified by its children, not needed
 			// 
-			PdfOperator::Operands::iterator oper = operands.begin ();
-			for (; oper != operands.end (); ++oper)
-			{
-				if (hasValidPdf(*oper))
-				{ // We do not support adding operators from another stream so if
-				  // it has valid pdf, it has to be the same
-					if ( ((*oper)->getPdf() != &pdf) || !((*oper)->getIndiRef() == rf) )
-					{
-						kernelPrintDbg (debug::DBG_CRIT, "Pdf or indiref do not match: want " << rf << 
-														 " op has" <<(*oper)->getIndiRef());
-						throw CObjInvalidObject ();
-					}
-				
-					
-				}else
-				{
-					(*oper)->setPdf (&pdf);
-					(*oper)->setIndiRef (rf);
-					(*oper)->registerObserver (observer);
-					(*oper)->lockChange ();
-				}
-			}
+			if (0 < it.getCurrent()->getParametersCount())
+				it.getCurrent()->init_operands (observer, &pdf, &rf);
 			
 			it = it.next ();
 		}
@@ -152,7 +135,7 @@ namespace {
 			}
 
 			// 
-			// If xpdf returned an Int, bu the operand can be a real convert it
+			// If xpdf returned an Int, but the operand can be a real convert it
 			// 
 			if (isInt(*it))
 			{
@@ -985,28 +968,26 @@ CContentStream::insertOperator (OperatorIterator it, boost::shared_ptr<PdfOperat
 //
 void 
 CContentStream::frontInsertOperator (boost::shared_ptr<PdfOperator> newoper, 
-									 bool indicateChange)
+		bool indicateChange)
 {
-	assert (!cstreams.empty());
-
-	// Check whether we can make the change
-	cstreams.front()->canChange();
-
-	if (operators.empty ())
-	{ // Insert into empty contentstream
-		
-		operators.push_back (newoper);
-	
-	}else
-	{ // Insert into
-
 		assert (!cstreams.empty());
 		// Set correct IndiRef, CPdf and cs to inserted operator
 		assert (hasValidRef (cstreams.front()));
 		assert (hasValidPdf (cstreams.front()));
-		CPdf* pdf = cstreams.front()->getPdf();
+
+	// Check whether we can make the change
+	cstreams.front()->canChange();
+	IndiRef rf = cstreams.front()->getIndiRef ();
+	CPdf* pdf = cstreams.front()->getPdf();
 		assert (pdf);
-		IndiRef rf = cstreams.front()->getIndiRef ();
+	// set accordingly	
+	opsSetPdfRefCs (newoper, *pdf, rf, *this, operandobserver);
+
+	if (operators.empty ())
+	{ // Insert into empty contentstream
+		operators.push_back (newoper);
+	}else
+	{ // Insert into
 		opsSetPdfRefCs (newoper, *pdf, rf, *this, operandobserver);
 
 		shared_ptr<PdfOperator> secondoper = operators.front();
@@ -1036,8 +1017,8 @@ CContentStream::frontInsertOperator (boost::shared_ptr<PdfOperator> newoper,
 //
 void
 CContentStream::replaceOperator (OperatorIterator it, 
-								 boost::shared_ptr<PdfOperator> newOper, 
-								 bool indicateChange)
+		boost::shared_ptr<PdfOperator> newOper, 
+		bool indicateChange)
 {
 	kernelPrintDbg (debug::DBG_DBG, "");
 	assert (!operators.empty());
@@ -1147,7 +1128,7 @@ CContentStream::registerCStreamObservers () const
 	{
 		// Register cstream observer
 		for (CStreams::const_iterator it = cstreams.begin(); it != cstreams.end(); ++it)
-			(*it)->registerObserver (cstreamobserver);
+			REGISTER_SHAREDPTR_OBSERVER((*it), cstreamobserver);
 	}else
 	{
 		assert (!"Observer is not initialized.");
@@ -1165,7 +1146,7 @@ CContentStream::unregisterCStreamObservers () const
 	{
 		// Unregister cstream observer
 		for (CStreams::const_iterator it = cstreams.begin(); it != cstreams.end(); ++it)
-			(*it)->unregisterObserver (cstreamobserver);
+			UNREGISTER_SHAREDPTR_OBSERVER((*it), cstreamobserver);
 	}else
 	{
 		assert (!"Observer is not initialized.");
