@@ -1,30 +1,35 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
-// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
-/* 
- * =====================================================================================
- *        Filename:  cdict.h
- *     Description:  Header file containing definition of IProperty and CObject classes.
- *         Created:  01/18/2006 
- *          Author:  jmisutka (06/01/19), 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
  *
- * =====================================================================================
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
+// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 #ifndef _CDICT_H
 #define _CDICT_H
 
 // all basic includes
-#include "static.h"
-#include "iproperty.h"
-#include "cobjectsimple.h"
-#include "carray.h"
+#include "kernel/static.h"
+#include "kernel/iproperty.h"
+#include "kernel/cobjectsimple.h"
+#include "kernel/carray.h"
 
 
 //=====================================================================================
@@ -65,8 +70,8 @@ class CDict : noncopyable, public IProperty
 	
 public:
 	typedef std::list<std::pair<std::string, boost::shared_ptr<IProperty> > > Value; 
-	typedef const std::string& 			WriteType; 
-	typedef const std::string& 			PropertyId;
+	typedef const std::string& WriteType; 
+	typedef const std::string& PropertyId;
 	typedef observer::ComplexChangeContext<IProperty, PropertyId> CDictComplexObserverContext;
 
 	/** 
@@ -131,7 +136,9 @@ protected:
 	 * @return New complex object.
 	 */
 	virtual CDict* _newInstance () const
-		{ return new CDict; }
+	{ 
+		return new CDict; 
+	}
 	
 	//
 	// Get methods
@@ -246,7 +253,7 @@ public:
 	 * the cloned object is added.
 	 * Indicate that this object has changed and return the pointer to the cloned object.
 	 *
-	 * @param newIp 		New property.
+	 * @param newIp New property.
 	 * @return Pointer to the new property.
 	 *
 	 * \exception OutOfRange Thrown when property not found.
@@ -259,7 +266,6 @@ public:
 	 */
 	boost::shared_ptr<IProperty> addProperty (const std::string& propertyName, const IProperty& newIp);
 
-	
 	/**
 	 * Remove property from dictionary. 
 	 *
@@ -333,7 +339,7 @@ private:
 	 * @param context Context in which a change occured.
 	 */
 	void _objectChanged (boost::shared_ptr<IProperty> newValue, 
-						 boost::shared_ptr<const ObserverContext> context);
+			boost::shared_ptr<const ObserverContext> context);
 
 	//
 	// Mode interface
@@ -357,7 +363,7 @@ public:
 	void _getAllChildObjects (Storage& store) const
 	{
 		Value::const_iterator it = value.begin ();
-		for	(; it != value.end (); ++it)
+		for(; it != value.end (); ++it)
 			store.push_back ((*it).second);
 	}
 
@@ -479,15 +485,13 @@ size_t streamToCharBuffer (Object & streamObject, Ref ref, CharBuffer & outputBu
  */
 void xpdfObjToString (Object& obj, std::string& str);
 
-
 /**
  * Get string from xpdf stream object.
  *
  * @param str Output string.
  * @param obj Xpdf stream object.
  */
-void
-getStringFromXpdfStream (std::string& str, ::Object& obj);
+void getStringFromXpdfStream (std::string& str, ::Object& obj);
 
 
 //=========================================================
@@ -647,13 +651,17 @@ getDoubleFromDict (const IP& ip, const std::string& id)
 template<typename IP>
 inline std::string
 getStringFromDict (const IP& ip, const std::string& id)
-	{ return getSimpleValueFromDict<CString> (ip, id);}
+{ 
+	return getSimpleValueFromDict<CString> (ip, id);
+}
 
 /** Get name from dictionary. */
 template<typename IP>
 inline std::string
 getNameFromDict (const IP& ip, const std::string& id)
-	{ return getSimpleValueFromDict<CName> (ip, id);}
+{ 
+	return getSimpleValueFromDict<CName> (ip, id);
+}
 
 //=========================================================
 //	CDict "set value" helper methods
@@ -751,7 +759,9 @@ setSimpleValueInDict (const IProperty& ip, CDict::PropertyId name, const typenam
 template<typename IP>
 inline void
 setIntInDict (const IP& ip, const std::string& name, int val)
-	{ setSimpleValueInDict<int, CInt, pInt> (ip, name, val);}
+{ 
+	setSimpleValueInDict<int, CInt, pInt> (ip, name, val);
+}
 
 /** Set	double in dictioary. */
 template<typename IP>
@@ -834,7 +844,9 @@ getTypeFromDictionary (const boost::shared_ptr<CDict>& dict, CDict::PropertyId k
 	// Check the type
 	if (ItemType::type != ip->getType ())
 	{
-		utilsPrintDbg (debug::DBG_DBG, "wanted type " << ItemType::type << " got " << ip->getType () << " key[" << key << "]");
+		utilsPrintDbg (debug::DBG_DBG, "wanted type " << ItemType::type 
+				<< " got " << ip->getType () 
+				<< " key[" << key << "]");
 		std::string err= "getTypeFromDictionary() [" + key + "]";
 		throw ElementBadTypeException (err);
 	}
@@ -896,7 +908,9 @@ getTypeFromDictionary (const boost::shared_ptr<IProperty>& ip, CDict::PropertyId
 template<typename IP>
 inline boost::shared_ptr<CDict>
 getCDictFromDict (IP& ip, const std::string& key)
-	{return getTypeFromDictionary<CDict> (ip, key);}
+{
+	return getTypeFromDictionary<CDict> (ip, key);
+}
 
 /** 
  * Get array from dictionary. If it is an indirect object, fetch the object.
@@ -904,7 +918,9 @@ getCDictFromDict (IP& ip, const std::string& key)
 template<typename IP>
 inline boost::shared_ptr<CArray>
 getCArrayFromDict (IP& ip, const std::string& key)
-	{return getTypeFromDictionary<CArray> (ip, key);}
+{
+	return getTypeFromDictionary<CArray> (ip, key);
+}
 
 
 /** 
@@ -912,7 +928,9 @@ getCArrayFromDict (IP& ip, const std::string& key)
  */
 inline boost::shared_ptr<CDict>
 getCDictFromDict (boost::shared_ptr<CDict> dict, const std::string& key)
-	{return getTypeFromDictionary<CDict> (dict, key);}
+{
+	return getTypeFromDictionary<CDict> (dict, key);
+}
 
 
 //=====================================================================================
