@@ -1,78 +1,83 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
-// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
-/* 
- * =====================================================================================
- *        Filename:  cobjectsimple.h
- *     Description:  Header file containing definition of simple cobjects.
- *         Created:  01/18/2006 
- *          Author:  jmisutka (06/01/19), 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
  *
- * =====================================================================================
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
+// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 #ifndef _COBJECTSIMPLE_H
 #define _COBJECTSIMPLE_H
 
 // all basic includes
-#include "static.h"
-#include "iproperty.h"
+#include "kernel/static.h"
+#include "kernel/iproperty.h"
 
 
 //=====================================================================================
 namespace pdfobjects {
 //=====================================================================================
 
-		
 /**
  * CObjectSimple type trait.
  *
  * This is an advance c++ template technique which allows us to store
- * additional information that identify variable type (e.g. function type specification of a function template --
- * method in a template class).
- *
- * If someone tries to use unsupported type (e.g pCmd, etc.), she should get compile error
- * because PropertyTraitSimple<> has no body.
- *
- * REMARK: BE CAREFUL when manipulating these ones. Small change could resulting
- * in an error could be very difficult to find.
+ * additional information that identify variable type (e.g. function 
+ * type specification of a function template -- method in a template 
+ * class).
+ * <br>
+ * If someone tries to use unsupported type (e.g pCmd, etc.), she 
+ * should get compile error because PropertyTraitSimple<> has no body.
+ * <br>
+ * REMARK: BE CAREFUL when manipulating these ones. Small change could 
+ * resulting in an error could be very difficult to find.
  *
  * \see CDict, CArray, CObjectStream
  */
 template<PropertyType T> struct PropertyTraitSimple; 
 template<> struct PropertyTraitSimple<pNull>
-{	public: typedef NullType		value;
-	public: typedef NullType		writeType; 
+{	public: typedef NullType value;
+	public: typedef NullType writeType; 
 };
 template<> struct PropertyTraitSimple<pBool>
-{	public: typedef bool			value;
-	public: typedef bool			writeType; 
+{	public: typedef bool value;
+	public: typedef bool writeType; 
 };
-template<> struct PropertyTraitSimple<pInt>	
-{	public: typedef int				value;
-	public: typedef int				writeType; 
+template<> struct PropertyTraitSimple<pInt>
+{	public: typedef int value;
+	public: typedef int writeType; 
 };
-template<> struct PropertyTraitSimple<pReal>	
-{	public: typedef double			value;
-	public: typedef double 			writeType; 
+template<> struct PropertyTraitSimple<pReal>
+{	public: typedef double value;
+	public: typedef double writeType; 
 };
 template<> struct PropertyTraitSimple<pString> 
-{	public: typedef std::string			value;
-	public: typedef const std::string& 	writeType; 
+{	public: typedef std::string value;
+	public: typedef const std::string& writeType; 
 };
-template<> struct PropertyTraitSimple<pName>	
-{	public: typedef std::string			value;
-	public: typedef const std::string& 	writeType; 
+template<> struct PropertyTraitSimple<pName>
+{	public: typedef std::string value;
+	public: typedef const std::string& writeType; 
 };
-template<> struct PropertyTraitSimple<pRef> 	
-{	public: typedef IndiRef				value;
-	public: typedef const IndiRef&	 	writeType; 
+template<> struct PropertyTraitSimple<pRef> 
+{	public: typedef IndiRef value;
+	public: typedef const IndiRef& writeType; 
 };
 
 
@@ -98,9 +103,9 @@ template <PropertyType Tp>
 class CObjectSimple : noncopyable, public IProperty
 {
 public:
-	typedef typename PropertyTraitSimple<Tp>::writeType	 WriteType;
-	typedef typename PropertyTraitSimple<Tp>::value 	 Value;
-	typedef observer::BasicChangeContext<IProperty>		 BasicObserverContext;
+	typedef typename PropertyTraitSimple<Tp>::writeType WriteType;
+	typedef typename PropertyTraitSimple<Tp>::value Value;
+	typedef observer::BasicChangeContext<IProperty> BasicObserverContext;
 
 	/** 
 	 * Type of the property.
@@ -108,12 +113,10 @@ public:
 	 * This association allows us to get the PropertyType from object type.
 	 */
 	static const PropertyType type = Tp;
-
 private:
 	/** Simple value. */
 	Value value;
 	
-
 	//
 	// Constructors
 	//
@@ -123,22 +126,19 @@ public:
 	 * Constructor. 
 	 * The object will read value from o and store it. We do NOT save any reference to o.
 	 *
-	 * @param p		Pointer to pdf object.
-	 * @param o		Xpdf object. 
-	 * @param rf	Indirect id and gen id.
+	 * @param p Pointer to pdf object.
+	 * @param o Xpdf object. 
+	 * @param rf Indirect id and gen id.
 	 */
 	CObjectSimple (CPdf& p, Object& o, const IndiRef& rf);
-
 	
 	/**
 	 * Constructor.
 	 * The object will read value from o and store it. We do NOT save any reference to o.
 	 *
-	 * @param o		Xpdf object. 
+	 * @param o Xpdf object. 
 	 */
 	CObjectSimple (Object& o);
-
-
 public:	
 
 	/**
@@ -146,7 +146,7 @@ public:
 	 * as a standalone and does not belong to any pdf. When added to a pdf
 	 * the relation will be saved to IProperty::pdf.
 	 *
-	 * @param val	Value that will this object hold.
+	 * @param val Value that will this object hold.
 	 */
 	CObjectSimple (const Value& val = Value());
 
@@ -177,14 +177,13 @@ public:
 	 * @return Type of this property.
 	 */
 	virtual PropertyType getType () const {return type;}
-			
 
 	/**
 	 * Returns string representation of this object according to pdf
 	 * specification. 
 	 * 
-	 * @param str 	Output string that will hold the string representation 
-	 * 				of current object.
+	 * @param str Output string that will hold the string representation 
+	 * of current object.
 	 */
 	virtual void getStringRepresentation (std::string& str) const;
 	
@@ -224,7 +223,7 @@ public:
 	 *
 	 * \see PropertyTraitSimple
 	 *
-	 * @param val	Value that will be set.
+	 * @param val Value that will be set.
 	 */
 	void setValue (WriteType val);
 
@@ -282,20 +281,19 @@ private:
 	 * @param context Context in which a change occured.
 	 */
 	void _objectChanged (boost::shared_ptr<const ObserverContext> context);
-
 };
 
 
 //
 // Typedefs
 //
-typedef CObjectSimple<pNull>	CNull;
-typedef CObjectSimple<pBool>	CBool;
-typedef CObjectSimple<pInt>		CInt;
-typedef CObjectSimple<pReal>	CReal;
-typedef CObjectSimple<pString> 	CString;
-typedef CObjectSimple<pName> 	CName;
-typedef CObjectSimple<pRef> 	CRef;
+typedef CObjectSimple<pNull> CNull;
+typedef CObjectSimple<pBool> CBool;
+typedef CObjectSimple<pInt> CInt;
+typedef CObjectSimple<pReal> CReal;
+typedef CObjectSimple<pString> CString;
+typedef CObjectSimple<pName> CName;
+typedef CObjectSimple<pRef> CRef;
 
 
 //=====================================================================================
@@ -310,16 +308,15 @@ namespace utils {
 /**
  * Make name valid.
  * 
-	Beginning with PDF 1.2, any character except null (character code 0) may be included
-	in a name by writing its 2-digit hexadecimal code, preceded by the number
-	sign character (#); see implementation notes 3 and 4 in Appendix H. This
-	syntax is required to represent any of the delimiter or white-space characters or
-	the number sign character itself; it is recommended but not required for characters
-	whose codes are outside the range 33 (!) to 126 (~). The examples shown in
-	Table 3.3 are valid literal names in PDF 1.2 and later.
-
- *	@param it Start iterator.
- *	@param end End iterator.
+ * Beginning with PDF 1.2, any character except null (character code 0) may be included
+ * in a name by writing its 2-digit hexadecimal code, preceded by the number
+ * sign character (#); see implementation notes 3 and 4 in Appendix H. This
+ * syntax is required to represent any of the delimiter or white-space characters or
+ * the number sign character itself; it is recommended but not required for characters
+ * whose codes are outside the range 33 (!) to 126 (~). The examples shown in
+ * Table 3.3 are valid literal names in PDF 1.2 and later.
+ * @param it Start iterator.
+ * @param end End iterator.
  */
 template<typename Iter>
 std::string 
@@ -331,11 +328,9 @@ makeNamePdfValid (Iter it, Iter end)
 	{
 		if ( '!' > (*it) || '~' < (*it))
 		{ // Convert it to ascii
-		
 			Item a = (Item) (*it) >> sizeof (Item) * 4;
 			Item b = (Item) (*it) & ((unsigned) 1 << sizeof(Item) * 4);
 			tmp += std::string ("#") + a + b;
-			
 		}else
 			tmp += *it;
 	}
@@ -346,25 +341,30 @@ makeNamePdfValid (Iter it, Iter end)
 /**
  * Make name valid.
  * 
-	Beginning with PDF 1.2, any character except null (character code 0) may be included
-	in a name by writing its 2-digit hexadecimal code, preceded by the number
-	sign character (#); see implementation notes 3 and 4 in Appendix H. This
-	syntax is required to represent any of the delimiter or white-space characters or
-	the number sign character itself; it is recommended but not required for characters
-	whose codes are outside the range 33 (!) to 126 (~). The examples shown in
-	Table 3.3 are valid literal names in PDF 1.2 and later.
-
- *	@param str Character string.
+ * Beginning with PDF 1.2, any character except null (character code 0) may be included
+ * in a name by writing its 2-digit hexadecimal code, preceded by the number
+ * sign character (#); see implementation notes 3 and 4 in Appendix H. This
+ * syntax is required to represent any of the delimiter or white-space characters or
+ * the number sign character itself; it is recommended but not required for characters
+ * whose codes are outside the range 33 (!) to 126 (~). The examples shown in
+ * Table 3.3 are valid literal names in PDF 1.2 and later.
+ *
+ * @param str Character string.
  */
 inline std::string 
-makeNamePdfValid (const char* str)
-	{ return makeNamePdfValid (&str[0], &str[strlen(str)]); }
+makeNamePdfValid (const char * str)
+{ 
+	return makeNamePdfValid (str, str + strlen(str)); 
+}
 
 /**
  * Make string pdf valid.
  *
- Any characters may appear in a string except unbalanced parentheses and
- the backslash, which must be treated specially.
+ * Any characters may appear in a string except unbalanced parentheses and
+ * the backslash, which must be treated specially.
+ * <br>
+ * This includes also \0 (NUL) character, therefore we can't use standard
+ * str* functions for strings.
  *
  * @param it Start iterator.
  * @param end End iterator.
@@ -393,19 +393,20 @@ makeStringPdfValid (Iter it, Iter end)
 }
 
 /**
- * 
  * Make string pdf valid.
  *
- Any characters may appear in a string except unbalanced parentheses and
- the backslash, which must be treated specially./
+ * Any characters may appear in a string except unbalanced parentheses and
+ * the backslash, which must be treated specially.
  *
  * @param str Character string.
  */
 inline std::string 
-makeStringPdfValid (const char* str)
-	{ return makeStringPdfValid (&str[0], &str[strlen(str)]); }
+makeStringPdfValid (GString * str)
+{ 
+	char * string = str->getCString();
+	return makeStringPdfValid (string, string + str->getLength()); 
+}
 
-	
 //=========================================================
 // Creation functions
 //=========================================================
@@ -433,16 +434,16 @@ IProperty* createObjFromXpdfObj (::Object& obj);
 /**
  * Save real xpdf object value to val.
  * 
- * @param obj	Xpdf object which holds the value.
- * @param val	Variable where the value will be stored.
+ * @param obj Xpdf object which holds the value.
+ * @param val Variable where the value will be stored.
  */
 template <PropertyType Tp,typename T> void simpleValueFromXpdfObj (::Object& obj, T val);
 
 /**
  * Create xpdf Object which represents value.
  * 
- * @param val	Value where the value is stored.
- * @return 		Xpdf object where the value is stored.
+ * @param val Value where the value is stored.
+ * @return Xpdf object where the value is stored.
  */
 template <PropertyType Tp,typename T> Object* simpleValueToXpdfObj (T val);
 
@@ -459,8 +460,8 @@ template <PropertyType Tp,typename T> Object* simpleValueToXpdfObj (T val);
 /**
  * Parses string to get simple values like int, name, bool etc.
  * 
- * @param str	String to be parsed.
- * @param val	Desired value.
+ * @param str String to be parsed.
+ * @param val Desired value.
  *
  * @throw ObjBadValueE Thrown when the string, can't be parsed correctly.
  */
@@ -474,7 +475,7 @@ void simpleValueFromString (const std::string& str, IndiRef& val);
 //=========================================================
 // To string functions
 //=========================================================
-		
+
 /**
  * Return simple xpdf object (null,number,string...) in string representation.
  * 
@@ -483,7 +484,7 @@ void simpleValueFromString (const std::string& str, IndiRef& val);
  * make other functions also template.
  *
  * @param val that will be converted to string.
- * @param str string
+ * @param str string.
  */
 template <PropertyType Tp> void simpleValueToString (bool val, std::string& str);
 
@@ -521,23 +522,13 @@ template <PropertyType Tp> void simpleValueToString (const IndiRef& val,std::str
 // Other functions
 //=========================================================
 
-/**
- * Free an object. We assume that all child objects (if any)
- * have been already freed.
- *
- * Copy & paste from Object.h
- * 
- * @param obj	Object to be freed.
- */
-void freeXpdfObject (Object* obj);
-
 /**
  * Returns true if object has a parent.
  *
  * \exception ObjInvalidOperation Thrown when the object does not belong
  * to a valid pdf.
  *
- * @param ip	IProperty of object. 
+ * @param ip IProperty of object. 
  */
 bool objHasParent (const IProperty& ip);
 
@@ -547,7 +538,7 @@ bool objHasParent (const IProperty& ip);
  * \exception ObjInvalidOperation Thrown when the object does not belong
  * to a valid pdf.
  *
- * @param ip	IProperty of object. 
+ * @param ip IProperty of object. 
  * @param indiObj Out parameter wheren indirect object will be saved, because
  * finding the object can be an expensive operation.
  */
@@ -555,7 +546,7 @@ bool objHasParent (const IProperty& ip, boost::shared_ptr<IProperty>& indiObj);
 
 
 //=========================================================
-//	CObject* "delegate" helper methods
+// CObject* "delegate" helper methods
 //=========================================================
 
 /**
@@ -567,7 +558,7 @@ boost::shared_ptr<IProperty> getReferencedObject (boost::shared_ptr<IProperty> i
 
 
 //=========================================================
-//	CObjectSimple "get value" helper methods
+// CObjectSimple "get value" helper methods
 //=========================================================
 
 /**
@@ -628,30 +619,34 @@ getValueFromSimple (const boost::shared_ptr<IProperty>& ip)
 /** Get int from ip. */
 inline int 
 getIntFromIProperty (const boost::shared_ptr<IProperty>& ip)
-	{return getValueFromSimple<CInt> (ip);}
+{
+	return getValueFromSimple<CInt> (ip);
+}
 
 /** Get double from ip. */
 inline double 
 getDoubleFromIProperty (const boost::shared_ptr<IProperty>& ip)
 {
-	return (isInt (ip)) ? getValueFromSimple<CInt> (ip) :
-						 getValueFromSimple<CReal> (ip);
+	return (isInt (ip)) ? getValueFromSimple<CInt> (ip) : 
+		getValueFromSimple<CReal> (ip);
 }
 
 /** Get string from ip. */
 inline std::string
 getStringFromIProperty (const boost::shared_ptr<IProperty>& ip)
-		{return getValueFromSimple<CString> (ip);}
-	
+{
+	return getValueFromSimple<CString> (ip);
+}
+
 /** Get name from ip. */
 inline std::string
 getNameFromIProperty (const boost::shared_ptr<IProperty>& ip)
-		{return getValueFromSimple<CName> (ip);}
-	
-
+{
+	return getValueFromSimple<CName> (ip);
+}
 
 //=========================================================
-//	CObjectSimple "set value" helper methods
+// CObjectSimple "set value" helper methods
 //=========================================================
 
 /**
@@ -689,7 +684,7 @@ setValueToSimple (const boost::shared_ptr<IProperty>& ip, const Value& val)
 //
 // Include the actual implementation of CObject class
 //
-#include "cobjectsimpleI.h"
+#include "kernel/cobjectsimpleI.h"
 
 
 #endif // _COBJECTSIMPLE_H
