@@ -1,135 +1,31 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
- *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
-// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 /*
- * $RCSfile: cxref.cc,v $
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * $Log: cxref.cc,v $
- * Revision 1.26  2007/02/04 20:17:02  mstsxfx
- * Common Licence comment for all cc and h files available in doc/licence_header
- * file and its content to all cc and h files in src/{gui,kernel,utils}
- * directories.
- * Xpdf code, QSA and QOutputDevice code are not touched
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
  *
- * Revision 1.25  2006/07/12 18:27:14  hockm0bm
- * minor changes - code comments etc.
- *
- * Revision 1.24  2006/06/27 18:19:48  hockm0bm
- * code formating - no code changed
- *
- * Revision 1.23  2006/06/27 17:27:49  hockm0bm
- * cosmetic changes
- *         - post-incrementation replaced by pre-incrementation (for performance)
- *         - thx to Jozo
- *
- * Revision 1.22  2006/06/25 16:25:08  hockm0bm
- * doc update - doxygen warnings removed (if they are real problem)
- *
- * Revision 1.21  2006/05/13 21:41:02  hockm0bm
- * * log messages update
- * * cleanUp reimplemented
- *         - doesn't use remove message on changedStorage
- * * reserveRef and newStorage
- *         - uses RefState
- *
- * Revision 1.20  2006/05/11 21:04:33  hockm0bm
- * doc update
- *
- * Revision 1.19  2006/05/10 16:59:05  hockm0bm
- * * changeObject throws if instance->clone fails
- * * changeTrailer throws if value->clone fails
- * 	- plus cloning is done
- * * getTrailerEntry throws if value can't be cloned
- * * getDocInfo throws if value can't be cloned
- * * getDocInfoNF throws if value can't be cloned
- * * fetch throws if value can't be cloned
- *
- * Revision 1.18  2006/05/09 20:06:43  hockm0bm
- * * stored field removed from ChangedEntry
- * * doc update
- *
- * Revision 1.17  2006/05/08 10:34:04  hockm0bm
- * * reserveRef throws exception if no indirect object is available
- * * fetch always returns cloned value (because of streams)
- *
- * Revision 1.16  2006/05/06 08:39:28  hockm0bm
- * knowsRef delegates to XRef::knowsRef if reference not available in newStorage
- *
- * Revision 1.15  2006/05/05 11:55:55  petrm1am
- *
- * Commiting changes sent by Michal:
- *
- * cpdf.cc:
- * * consolidatePageList bug fixed
- *     - difference += pageCount not -=
- * * debug messages improved
- *
- * cxref.cc:
- * * reserveRef bug fix
- *     - totalCount replaced by xrefCount from XRef::getNumObjects
- *     - num is initialized to -1
- *     - kernelPrintDbg message wrong position (cannot use new entry)
- *
- * Revision 1.14  2006/05/01 13:53:07  hockm0bm
- * new style printDbg
- *
- * Revision 1.13  2006/04/28 17:16:51  hockm0bm
- * * reserveRef bug fixes
- * 	- reusing didn't check whether reference is in newStorage
- * 	- also not realy free entries were considered (XRef marks
- * 	  all entries as free by default and allocates entries array
- * 	  by blocks, so all behind last real objects are free too but
- * 	  they are not free in pdf)
- * 	- gen number is not increase if reusing entry
- * 	- gen number == MAXOBJGEN is never reused
- * * MAXOBJNUM constant added
- * * MAXOBJGEN constant added
- *
- * Revision 1.12  2006/04/27 18:09:34  hockm0bm
- * * cleanUp method added
- * * debug messages minor changes
- * * changeTrailer handles trailer->update used correctly (key parameter)
- * * correct Object instancing
- *
- * Revision 1.11  2006/04/23 22:03:40  hockm0bm
- * reopen sets lastXRefPos to given offset
- *
- * Revision 1.10  2006/04/19 06:01:59  hockm0bm
- * reopen signature changed to enable jumping to start from specified offset
- *         - synchronization with XRef::initInternals method
- *
- * Revision 1.9  2006/04/17 17:45:47  hockm0bm
- * bug in knowsRef corrected
- *         - checking for object number added when accessing XRef::entries
- *
- * Revision 1.8  2006/04/15 08:04:43  hockm0bm
- * reserveRef and createObject are protected now
- *
- * Revision 1.7  2006/04/13 18:15:02  hockm0bm
- * * releaseStorage removed
- * * releaseObject method removed
- *
- * Revision 1.6  2006/03/31 16:09:56  hockm0bm
- * printDbg messages with ref changed
- *
- * Revision 1.5  2006/03/23 22:13:51  hockm0bm
- * printDbg added
- * exception handling
- * TODO removed
- * FIXME for revisions handling - throwing exeption
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
  *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
-#include "cxref.h"
+// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
+#include "kernel/static.h"
+#include "kernel/cxref.h"
 #include "utils/debug.h"
-#include "factories.h"
+#include "kernel/factories.h"
 
 using namespace pdfobjects;
 
@@ -144,7 +40,7 @@ using namespace debug;
 	// returned from remove object (iterators are not invalidated by remove
 	// method)
 	kernelPrintDbg(DBG_DBG, "Deallocating changedStorage (size="<<changedStorage.size()<<")");
-	ObjectStorage< ::Ref, ObjectEntry*, RefComparator>::Iterator i;
+	ObjectStorage< ::Ref, ObjectEntry*, xpdf::RefComparator>::Iterator i;
 	int index=0;
 	for(i=changedStorage.begin(); i!=changedStorage.end(); ++i)
 	{
@@ -170,7 +66,7 @@ using namespace debug;
 		}
 
 		kernelPrintDbg(DBG_DBG, "Deallocating entry for "<<ref<<" index="<<index<<")");
-		utils::freeXpdfObject(entry->object);
+		xpdf::freeXpdfObject(entry->object);
 		delete entry;
 		i->second=NULL;
 	}
@@ -292,7 +188,7 @@ using namespace debug;
 using namespace debug;
 
 	int i=1;
-	int num=-1, gen;
+	int num=-1, gen=0;
 
 	kernelPrintDbg(DBG_DBG, "");
 	
@@ -444,7 +340,7 @@ using namespace debug;
 	return obj;
 }
 
-RefState CXref::knowsRef(::Ref ref)
+RefState CXref::knowsRef(::Ref& ref)
 {
 using namespace debug;
 
@@ -683,7 +579,7 @@ using namespace debug;
 	kernelPrintDbg(DBG_DBG, "");
 
 	size_t newSize=0;
-	ObjectStorage< ::Ref, RefState, RefComparator>::Iterator begin, i;
+	ObjectStorage< ::Ref, RefState, xpdf::RefComparator>::Iterator begin, i;
 
 	for(i=newStorage.begin(); i!=newStorage.end(); ++i)
 		if(i->second==INITIALIZED_REF)
