@@ -1,26 +1,34 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
- *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
-// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 /*
- * =====================================================================================
- *        Filename:  pdfoperators.h
- *         Created:  03/26/2006 16:54:03 PM CET
- *          Author:  jmisutka ()
- * =====================================================================================
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
+// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 
 #ifndef _PDFOPERATORS_H_
 #define _PDFOPERATORS_H_
 
 // static includes
-#include "static.h"
+#include "kernel/static.h"
+#include "kernel/iproperty.h"
 #include "utils/iterator.h"
 
 //==========================================================
@@ -31,8 +39,9 @@ namespace pdfobjects {
 //
 // Forward declaration
 //
-class IProperty;
 class CContentStream;
+class CPdf;
+
 							 
 //==========================================================
 // PdfOperator
@@ -86,7 +95,7 @@ public:
 	typedef iterator::SharedDoubleLinkedListIterator<PdfOperator> Iterator;
 	typedef Iterator::ListItem							ListItem;
 	typedef std::list<boost::shared_ptr<PdfOperator> > 	PdfOperators;
-	typedef Rectangle									BBox;
+	typedef libs::Rectangle									BBox;
 
 	// iterator has to be a friend
 	friend class iterator::SharedDoubleLinkedListIterator<PdfOperator>;
@@ -401,6 +410,19 @@ public:
 	BBox getBBox () const
 		{ assert (BBox::isInitialized(bbox)); return bbox; }
 	
+
+	//
+	// Observer interface
+	//
+public:
+	/**
+	 * Init operands and store observer for later unregistering.
+	 */
+	virtual void init_operands (boost::shared_ptr<observer::IObserver<IProperty> >,
+								CPdf*,
+								IndiRef*)
+		{ throw NotImplementedException ("PdfOperator::register_operandobserver ()"); }
+
 };
 
 
@@ -568,6 +590,57 @@ public:
 protected:
 	virtual boost::shared_ptr<PdfOperator> clone ();
 
+	
+	//
+	// Observer interface
+	//
+private:
+	boost::shared_ptr<observer::IObserver<IProperty> > _operandobserver;
+public:
+	void init_operands (boost::shared_ptr<observer::IObserver<IProperty> > observer,
+						CPdf* pdf,
+						IndiRef* rf)
+	{ 
+		// store observer
+		_operandobserver = observer; 
+		//
+		for (Operands::iterator oper = operands.begin (); oper != operands.end (); ++oper)
+		{
+			if (hasValidPdf(*oper))
+			{ // We do not support adding operators from another stream
+				if ( ((*oper)->getPdf() != pdf) || !((*oper)->getIndiRef() == *rf) )
+				{
+					kernelPrintDbg (debug::DBG_CRIT, "Pdf or indiref do not match: want " << *rf <<  " op has" <<(*oper)->getIndiRef());
+					throw CObjInvalidObject ();
+				}
+				
+			}else
+			{
+				(*oper)->setPdf (pdf);
+				(*oper)->setIndiRef (*rf);
+				REGISTER_SHAREDPTR_OBSERVER((*oper), observer);
+				(*oper)->lockChange ();
+			}
+		} // for
+	}
+
+	//
+	// Destructor
+	//
+public:
+	
+	/**
+	 * Destructor.
+	 */
+	virtual ~SimpleGenericOperator() 
+	{
+			// can happen when used as a temporary object
+			if (0 < operands.size() && !(_operandobserver)) 
+				return;
+		for (Operands::iterator it = operands.begin(); it != operands.end(); ++it) {
+			UNREGISTER_SHAREDPTR_OBSERVER ((*it), _operandobserver);
+		}
+	}
 };
 
 
