@@ -1,31 +1,36 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
- *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
-// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 /*
- * =====================================================================================
- *        Filename:  ccontentstream.cc
- *         Created:  03/24/2006 10:33:34 PM CET
- *          Author:  jmisutka, mjahoda
- * =====================================================================================
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
+// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 
 // static
-#include "static.h"
+#include "kernel/static.h"
 
 //
-#include "stateupdater.h"
-#include "pdfoperators.h"
-#include "cobject.h"
+#include "kernel/stateupdater.h"
+#include "kernel/pdfoperators.h"
+#include "kernel/cobject.h"
 
-//fabs
-#include <math.h>
 
 //==========================================================
 namespace pdfobjects {
@@ -322,19 +327,19 @@ namespace {
 	GfxState *
 	opTfUpdate (GfxState* state, boost::shared_ptr<GfxResources> res, const boost::shared_ptr<PdfOperator>, const PdfOperator::Operands& args, BBox* rc)
 	{
-		assert (2 <= args.size ());
+			assert (2 <= args.size());
 		// Set edge of rectangle from actual position on output devices
 		state->transform(state->getCurX (), state->getCurY(), & rc->xleft, & rc->yleft);
 		rc->xright = rc->xleft;
 		rc->yright = rc->yleft;
 
-		assert( isName( args[0] ) );
+			assert (isName(args[0]));
 		std::string val;
-		IProperty::getSmartCObjectPtr<CName> (args[0]) ->getValue (val);
+		IProperty::getSmartCObjectPtr<CName>(args[0])->getValue (val);
 
-		GfxFont *font = NULL;
+		GfxFont* font = NULL;
 
-		if (!(font = res.get()->lookupFont (val.c_str())))
+		if (!(font = res->lookupFont (val.c_str())))
 			return state;		// same as displaing with xpdf/Gfx
 		
 		state->setFont (font, getDoubleFromIProperty (args[1]));
@@ -725,13 +730,13 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 	double riseX, riseY;
 	CharCode code;
 	Unicode u[8];
-	double x, y, dx, dy, dx2, dy2, curX, curY, tdx, tdy, lineX, lineY;
+	double x, y, dx, dy,/* dx2, dy2,*/ curX, curY, tdx, tdy, lineX, lineY;
 	double originX = 0, originY, tOriginX, tOriginY;
 	double oldCTM[6], newCTM[6];
 	double *mat = NULL;
-	Dict *resDict = NULL;
+	//Dict *resDict = NULL;
 	char *p;
-	int len = 0, n = 0, uLen = 0, nChars = 0, nSpaces = 0, i = 0;
+	int len = 0, n = 0, uLen = 0,/* nChars = 0, nSpaces = 0,*/ i = 0;
 	GString s (txt.c_str(),txt.size());
 
 	font = state->getFont();
@@ -747,7 +752,7 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 		// Default type3 font heignt
 		double heightType3Font = DEFAULT_TYPE3_FONT_HEIGHT;
 
-		BBox h_rc();
+		BBox h_rc;
 
 		mat = state->getCTM();
 		for (i = 0; i < 6; ++i) {
@@ -779,8 +784,8 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 		while (len > 0) 
 		{
 		  n = font->getNextChar(p, len, &code,
-								u, (int)(sizeof(u) / sizeof(Unicode)), &uLen,
-								&dx, &dy, &originX, &originY);
+				  u, (int)(sizeof(u) / sizeof(Unicode)), &uLen,
+				  &dx, &dy, &originX, &originY);
 		  
 		  //
 		  // Try to find out the height and width of this letter
@@ -790,7 +795,12 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 		  if (charProc->isStream())
 		  {
 			  // Make parser
-			  scoped_ptr<Parser> parser (new ::Parser (NULL, new ::Lexer(NULL, charProc->getStream())));
+			  charProc->getStream()->incRef();	// FIX - charproc's stream was deallocated in ~Lexer
+			  scoped_ptr<Parser> parser (new ::Parser (NULL, 
+						  new ::Lexer(NULL, charProc->getStream()),
+						  gFalse
+						  )
+					  );
 			  xpdf::XpdfObject obj;
 			  // Read till BI found
 			  while (!parser->eofOfActualStream() && !obj->isCmd("BI"))
@@ -843,6 +853,8 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 			} // if (charProc->isStream())
 
 			// Free resources
+				assert (2 == charProc->getStream()->incRef());
+				assert (1 == charProc->getStream()->decRef());
 			charProc.reset ();
 
 			//
