@@ -1,167 +1,33 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 // vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 
-/*
- * $RCSfile: xrefwriter.cc,v $
- *
- * $Log: xrefwriter.cc,v $
- * Revision 1.30  2007/02/04 20:17:03  mstsxfx
- * Common Licence comment for all cc and h files available in doc/licence_header
- * file and its content to all cc and h files in src/{gui,kernel,utils}
- * directories.
- * Xpdf code, QSA and QOutputDevice code are not touched
- *
- * Revision 1.29  2006/08/25 17:25:43  petrm1am
- * typo
- *
- * Revision 1.28  2006/06/27 17:27:49  hockm0bm
- * cosmetic changes
- *         - post-incrementation replaced by pre-incrementation (for performance)
- *         - thx to Jozo
- *
- * Revision 1.27  2006/06/17 15:04:48  misuj1am
- *
- * -- include rem/add
- *
- * Revision 1.26  2006/05/30 17:29:34  hockm0bm
- * collectRevisions bug fixed
- *         - if pdf is linearized adds XRef::lastXRefPos to revisions,
- *           so linearized documents have 1 reference
- *
- * Revision 1.25  2006/05/24 19:32:17  hockm0bm
- * checkLinearized mem leak fixed
- *         - deallocates first parsed object
- *
- * Revision 1.24  2006/05/23 19:08:37  hockm0bm
- * XRefWriter::save uses return value from IPdfWriter::writeTrailer
- *
- * Revision 1.23  2006/05/17 19:40:07  hockm0bm
- * * getRevisionEnd
- *         - signature changed - uses position where to start searching
- *           not using current revision information
- *         - position is restored before return
- *         - method is protected now
- * * getRevisionSize method added
- *
- * Revision 1.22  2006/05/16 18:01:00  hockm0bm
- * pdf field value may be NULL - makes sense for stand alone XRefWriter instances
- *
- * Revision 1.21  2006/05/13 22:16:31  hockm0bm
- * * memory leak removed
- *         - changeObject didn't deallocate object returned from CXRef (previously changed value)
- *         - pdfWriter is deallocated in destructor
- * * ~XRefWriter destructor added
- * * log messages improved
- * * uses RefState
- *
- * Revision 1.20  2006/05/10 17:00:06  hockm0bm
- * collectRevisions
- *         - trailer clone success tested
- *
- * Revision 1.19  2006/05/09 20:08:31  hockm0bm
- * * collectRevisions
- * 	- considers also xref streams
- * 	- checks for endless loop caused by wrong Trailer::Prev values (cycle)
- * * checkLinearized new parameter xref needed for proper parsing
- *
- * Revision 1.18  2006/05/08 22:21:56  hockm0bm
- * * isLinearized method added
- *         - linearized field added
- * * checkLinearized is called in constructor
- * * saveChages prints WARNING if file is linearized
- * * changeRevision throws an exception if file is linearized
- * * collectRevisions doesn't collect if file is linearized
- *
- * Revision 1.17  2006/05/08 21:24:33  hockm0bm
- * checkLinearized function added
- *
- * Revision 1.16  2006/05/08 20:17:42  hockm0bm
- * * key words removed from here
- * * new model of data writing
- *         - uses IPdfWriter interface for implementation specific writer
- *         - uses OldStylePdfWriter by default
- *         - new implementator can be set by setPdfWriter method
- *         - saveChanges collects object from changedStorage and uses IPdfWriter
- *           to write them to the stream so it is independed on implementation
- *
- * Revision 1.15  2006/05/06 08:40:20  hockm0bm
- * knowsRef delegates to XRef::knowsRef if not in the newest revision
- *
- * Revision 1.14  2006/05/01 13:53:08  hockm0bm
- * new style printDbg
- *
- * Revision 1.13  2006/04/27 18:21:09  hockm0bm
- * * deallocation of Object corrected
- * * changeRevision
- *         - saves revision
- *
- * Revision 1.12  2006/04/23 13:13:20  hockm0bm
- * * getRevisionEnd method added
- *         - to get end of stream contnet for current revision
- * * cloneRevision method added
- *         - to support cloning of pdf in certain revision
- *
- * Revision 1.11  2006/04/21 20:38:08  hockm0bm
- * saveChanges writes indirect objects correctly
- *         - uses createIndirectObjectStringFromString method
- *
- * Revision 1.10  2006/04/20 22:32:09  hockm0bm
- * just debug message added
- *
- * Revision 1.9  2006/04/19 06:00:23  hockm0bm
- * * changeRevision - first implementation (not tested yet)
- * * collectRevisions -  first implementation (not tested yet)
- * * minor changes in saveChanges
- *
- * Revision 1.8  2006/04/17 19:57:30  hockm0bm
- * * findPDFEof removed
- *         - uses XRef eofPos value instead
- * * string constants for pdf markers
- *         - TRAILER_KEYWORD, XREF_KEYWORD, STARTXREF_KEYWORD
- * * minor changes in saveChanges method and buildXref
- *         - first testing - seems to work, but needs to test
- *
- * Revision 1.7  2006/04/13 18:08:49  hockm0bm
- * * releaseObject method removed
- * * readOnly mode removed - makes no sense in here
- * * documentation updated
- * * contains information about CPdf
- *         - because of pdf read only mode
- * * buildXref method added
- * * XREFROWLENGHT and EOFMARKER macros added
- *
- * Revision 1.6  2006/04/12 17:52:25  hockm0bm
- * * saveChanges method replaces saveXRef method
- *         - new semantic for saving changes
- *              - temporary save
- *              - new revision save
- *         - storePos field added to mark starting
- *           place where to store changes
- *         - saveChanges moves with storePos if new
- *           revision is should be created
- * * findPDFEof function added
- * * StreamWriter in place of BaseStream
- *         - all changes will be done via StreamWriter
- *
- * Revision 1.5  2006/03/23 22:13:51  hockm0bm
- * printDbg added
- * exception handling
- * TODO removed
- * FIXME for revisions handling - throwing exeption
- *
- *
- */
-#include "xrefwriter.h"
-#include "cpdf.h"
-#include "cobject.h"
+#include "kernel/static.h"
+#include<errno.h>
+#include "kernel/xrefwriter.h"
+#include "kernel/cpdf.h"
+#include "kernel/cobject.h"
 
 using namespace debug;
 
@@ -187,7 +53,8 @@ bool checkLinearized(StreamWriter & stream, XRef * xref, Ref * ref)
 	Parser parser=Parser(
 			xref, new Lexer(
 				NULL, stream.makeSubStream(stream.getPos(), false, 0, &obj)
-				)
+				),
+			gTrue
 			);
 
 	while(stream.getPos() < FIRST_LINEARIZED_BLOCK)
@@ -281,8 +148,6 @@ using namespace utils;
 
 bool XRefWriter::paranoidCheck(::Ref ref, ::Object * obj)
 {
-	bool reinicialization=false;
-
 	kernelPrintDbg(DBG_DBG, ref<<" type="<<obj->getType());
 
 	if(mode==paranoid)
@@ -351,7 +216,7 @@ void XRefWriter::changeObject(int num, int gen, ::Object * obj)
 	Object * oldValue=CXref::changeObject(ref, obj);
 	// deallocates previous changed value (if any)
 	if(oldValue)
-		utils::freeXpdfObject(oldValue);
+		xpdf::freeXpdfObject(oldValue);
 }
 
 ::Object * XRefWriter::changeTrailer(const char * name, ::Object * value)
@@ -474,7 +339,7 @@ using namespace utils;
 
 	// gets vector of all changed objects
 	IPdfWriter::ObjectList changed;
-	ObjectStorage< ::Ref, ObjectEntry *, RefComparator>::Iterator i;
+	ObjectStorage< ::Ref, ObjectEntry *, xpdf::RefComparator>::Iterator i;
 	for(i=changedStorage.begin(); i!=changedStorage.end(); ++i)
 	{
 		::Ref ref=i->first;
@@ -512,6 +377,143 @@ using namespace utils;
 	kernelPrintDbg(DBG_DBG, "finished");
 }
 
+#define ERR_OFFSET (size_t)(-1UL)
+#define isERR_OFFSET(value) (value == ERR_OFFSET)
+
+/** Gets value of the Prev field from given trailer.
+ * @param trailer Trailer stream or dictionary.
+ *
+ * This method correctly distinguishes between trailer dictionary and stream.
+ * @return Value of the Prev field or -1 on error (Prev not present or invalid
+ * value).
+ */
+size_t getPrevFromTrailer(Object * trailer)
+{
+	Dict * trailerDict = NULL;
+	if(trailer->isDict())
+		trailerDict = trailer->getDict();
+	else if(trailer->isStream())
+		trailerDict = trailer->getStream()->getDict();
+	else
+	{
+		kernelPrintDbg(DBG_ERR, "bad trailer type (type="<<
+				trailer->getType()<<")");
+		return ERR_OFFSET;
+	}
+
+	// gets prev field from current trailer and if it is null object (not
+	// present) or doesn't have integer value, jumps out of loop
+	Object prev;
+	trailerDict->lookupNF("Prev", &prev);
+	if(prev.getType()!=objInt)
+	{
+		kernelPrintDbg(DBG_DBG, "Prev doesn't have int value. type="
+				<<prev.getType()<<
+				". Assuming no more revisions.");
+		prev.free();
+		return ERR_OFFSET;
+	}
+
+	// releases prev because we don't need it anymore
+	int value=prev.getInt();
+	if(value<0)
+		return ERR_OFFSET;
+	return value;
+}
+
+int XRefWriter::getOldStyleTrailer(Object * trailer, size_t off)
+{
+	// old style cross reference table, we have to skip whole table and
+	// then we will get to trailer
+	kernelPrintDbg(DBG_INFO, "New old style cross reference section found. off="<<off);
+	
+	// searches for TRAILER_KEYWORD to be able to parse older trailer (one
+	// for xref on off position) - this works only for oldstyle XRef tables
+	// not XRef streams
+	char * ret; 
+	char buffer[1024];
+	memset(buffer, '\0', sizeof(buffer));
+	// resets position in the stream because parser moves with position
+	str->setPos(off);
+	while((ret=str->getLine(buffer, sizeof(buffer)-1)))
+	{
+		if(strstr(buffer, STARTXREF_KEYWORD))
+		{
+			// we have reached startxref keyword and haven't found trailer
+			kernelPrintDbg(DBG_ERR, STARTXREF_KEYWORD<<" found but no trailer.");
+			return -1;
+		}
+		
+		if(strstr(buffer, TRAILER_KEYWORD))
+		{
+			// trailer found, parse it and set trailer to parsed one
+			kernelPrintDbg(DBG_DBG, "Trailer dictionary found");
+			
+			// we have to create new parser because we can't set
+			// position in parser to current in the stream
+			// TODO: can we reuse parser from collectRevisions here?
+			Object parseObj;
+			::Parser parser = Parser(this,
+				new Lexer(NULL, str->makeSubStream(str->getPos(), gFalse, 0, &parseObj)),
+				gTrue
+				);
+
+			// deallocates previous one before it is filled by new one
+			trailer->free();
+			parser.getObj(trailer);
+			if(!trailer->isDict())
+			{
+				kernelPrintDbg(DBG_ERR, "Trailer is not dictionary.");
+				return -1;
+			}
+
+			// everything ok, trailer is read and parsed and can be used
+			return 0;
+		}
+	}
+	// stream returned NULL, which means that no more data in stream is
+	// available
+	assert(!ret);
+	kernelPrintDbg(DBG_DBG, "end of stream but no trailer found");
+	return -1;
+}
+
+int XRefWriter::getStreamTrailer(Object * trailer, size_t off, ::Parser & parser)
+{
+	// gen number should follow
+	::Object obj;
+	parser.getObj(&obj);
+	if(!obj.isInt())
+		goto bad_header;
+	// We don't need to free obj here, because int is not
+	// allocated internally
+	// end of indirect object header is obj key word
+	parser.getObj(&obj);
+	if(!obj.isCmd("obj"))
+		goto bad_header;
+
+	// header of indirect object is ok, so parse trailer object
+	obj.free();
+	trailer->free();
+	parser.getObj(trailer);
+	if(!trailer->isStream())
+	{
+		kernelPrintDbg(DBG_ERR, "Trailer is supposed to be stream, but "
+				<<trailer->getType()<<" found.");
+		return -1;
+	}
+	
+	// xref stream object contains also trailer information, so parses
+	// stream object and uses just dictionary part
+	kernelPrintDbg(DBG_INFO, "New xref stream section. off="<<off);
+	return 0;
+
+bad_header:
+	kernelPrintDbg(DBG_ERR, "Trailer header corrupted.");
+	obj.free();
+	return -1;
+}
+
 void XRefWriter::collectRevisions()
 {
 	kernelPrintDbg(DBG_DBG, "");
@@ -543,160 +545,62 @@ void XRefWriter::collectRevisions()
 		kernelPrintDbg(DBG_ERR, "Unable to clone trailer. Ignoring revision collecting.");
 		return;
 	}
-	bool cont=true;
 
-	// TODO code clean up
 	do
 	{
-		kernelPrintDbg(DBG_DBG, "XRef offset for "<<revisions.size()<<" revision is "<<off);
-		// pushes current offset as last revision
+		// process current trailer (store offset and get previous
+		// if present) - we are starting with the newest one cloned
+		// above
+		kernelPrintDbg(DBG_DBG, "XRef offset for "<<
+				revisions.size()<<" revision is "<<off);
 		revisions.push_back(off);
-
-		// gets prev field from current trailer and if it is null object (not
-		// present) or doesn't have integer value, jumps out of loop
-		Object prev;
-		trailer->getDict()->lookupNF("Prev", &prev);
-		if(prev.getType()==objNull)
-		{
-			// objNull doesn't need free
-			kernelPrintDbg(DBG_DBG, "No previous revision.");
+		off = getPrevFromTrailer(trailer);
+		if(isERR_OFFSET(off))
+			// no more previous trailers
 			break;
-		}
-		if(prev.getType()!=objInt)
+
+		// checks whether given offset is already in revisions, which 
+		// would mean corrupted referencies (because of cycle in 
+		// trailers)
+		if(std::find(revisions.begin(), revisions.end(), 
+					(size_t)off) != revisions.end())
 		{
-			kernelPrintDbg(DBG_DBG, "Prev doesn't have int value. type="<<prev.getType()<<". Assuming no more revisions.");
-			prev.free();
+			kernelPrintDbg(DBG_ERR, "Trailer Prev points to already"
+				       "processed revision (endless loop). "
+				       "Assuming no more revisions.");
 			break;
 		}
 
-		// checks whether given offeset already is in revisions, which would
-		// mean corrupted referencies (because of cycle in trailers)
-		if(std::find(revisions.begin(), revisions.end(), (size_t)prev.getInt())!=revisions.end())
-		{
-			kernelPrintDbg(DBG_ERR, "Trailer Prev points to already processed revision (endless loop). Assuming no more revisions.");
-			break;
-		}
-
-		// sets new value for off
-		off=prev.getInt();
-		prev.free();
-
-		// off is first byte of cross reference section. It can be either xref
-		// key word or beginning of xref stream object
+		// off is the first byte of a cross reference section. 
+		// It can be either xref key word or beginning of the 
+		// xref stream object
 		str->setPos(off);
 		Object parseObj, obj;
 		::Parser parser = Parser(this,
-			new Lexer(NULL, str->makeSubStream(str->getPos(), gFalse, 0, &parseObj))
+			new Lexer(NULL, str->makeSubStream(str->getPos(), gFalse, 0, &parseObj)),
+			gTrue
 			);
 		parser.getObj(&obj);
 		if(obj.isCmd(XREF_KEYWORD))
 		{
-			// old style cross reference table, we have to skip whole table and
-			// then we will get to trailer
 			obj.free();
-			kernelPrintDbg(DBG_INFO, "New old style cross reference section found. off="<<off);
-			
-			// searches for TRAILER_KEYWORD to be able to parse older trailer (one
-			// for xref on off position) - this works only for oldstyle XRef tables
-			// not XRef streams
-			char * ret; 
-			char buffer[1024];
-			memset(buffer, '\0', sizeof(buffer));
-			// resets position in the stream because parser moves with position
-			str->setPos(off);
-			while((ret=str->getLine(buffer, sizeof(buffer)-1)))
-			{
-				if(strstr(buffer, STARTXREF_KEYWORD))
-				{
-					// we have reached startxref keyword and haven't found trailer
-					kernelPrintDbg(DBG_ERR, STARTXREF_KEYWORD<<" found but no trailer.");
-					goto xreferror;
-				}
-				
-				if(strstr(buffer, TRAILER_KEYWORD))
-				{
-					// trailer found, parse it and set trailer to parsed one
-					kernelPrintDbg(DBG_DBG, "Trailer dictionary found");
-					
-					// we have to create new parser because we can't set
-					// position in parser to current in the stream
-					::Parser parser = Parser(this,
-						new Lexer(NULL, str->makeSubStream(str->getPos(), gFalse, 0, &parseObj))
-						);
-
-					// deallocates previous one before it is filled by new one
-					trailer->free();
-					parser.getObj(trailer);
-					if(!trailer->isDict())
-					{
-						kernelPrintDbg(DBG_ERR, "Trailer is not dictionary.");
-						goto xreferror;
-					}
-
-					// everything ok, trailer is read and parsed and can be used
-					break;
-				}
-			}
-			if(!ret)
-			{
-				// stream returned NULL, which means that no more data in stream is
-				// available
-				kernelPrintDbg(DBG_DBG, "end of stream but no trailer found");
-				cont=false;
-			}
-			continue;
-		}
-
-		// xref key work no found, it may be xref stream object
-		if(obj.isInt())
+			if(getOldStyleTrailer(trailer, off)<0)
+				break;
+		}else if(obj.isInt())
 		{
+			// xref key work no found, it may be xref stream object
 			// gen number should follow
 			obj.free();
-			parser.getObj(&obj);
-			if(!obj.isInt())
-			{
-				obj.free();
-				goto xreferror;
-			}
-			
-			// end of indirect object header is obj key word
-			parser.getObj(&obj);
-			if(!obj.isCmd("obj"))
-			{
-				obj.free();
-				goto xreferror;
-			}
-
-			// header of indirect object is ok, so parser object itself
-			Object trailerStream;
-			parser.getObj(&trailerStream);
-			if(!trailerStream.isStream())
-			{
-				trailerStream.free();
-				goto xreferror;
-			}
-			trailerStream.getDict()->lookupNF("Type", &obj);
-			if(!obj.dictIs("XRef"))
-			{
-				obj.free();
-				trailerStream.free();
-				goto xreferror;
-			}
-			
-			// xref stream object contains also trailer information, so parses
-			// stream object and uses just dictionary part
-			kernelPrintDbg(DBG_INFO, "New xref stream section. off="<<off);
-			trailer->free();
-			trailer->initDict(trailerStream.getDict());
-			continue;
+			if(getStreamTrailer(trailer, off, parser))
+				break;
+		}else {
+			kernelPrintDbg(DBG_ERR, "Bad trailer definition. Dictionary or stream"
+					"expected, but "<<obj.getType()<<"found");
+			obj.free();
+			break;
 		}
-
-xreferror:
-		kernelPrintDbg(DBG_ERR, "Xref section offset doesn't point to xref start");
-		cont=false;
-
 	// continues only if no problem with trailer occures
-	}while(cont); 
+	}while(true); 
 
 	// deallocates the oldest one - no problem if the oldest is the newest at
 	// the same time, because we have used clone of trailer instance from XRef
@@ -749,13 +653,12 @@ size_t XRefWriter::getRevisionEnd(size_t xrefStart)const
 	// starts from given position
 	streamWriter->setPos(xrefStart);
 	char buffer[BUFSIZ];
-	size_t length=0;
 	memset(buffer, '\0', sizeof(buffer));
 	while(streamWriter->getLine(buffer, sizeof(buffer)))
 	{
 		if(!strncmp(buffer, STARTXREF_KEYWORD, strlen(STARTXREF_KEYWORD)))
 		{
-			// we have found startstreamWriter key word, next line should contain
+			// we have found start-xref key word, next line should contain
 			// value of offset - this information is not important, we just have
 			// to get behind and calculates number of bytes
 			streamWriter->getLine(buffer, sizeof(buffer));
@@ -785,10 +688,16 @@ using namespace debug;
 	size_t revisionEOF=getRevisionEnd(revisions[revision]);
 
 	kernelPrintDbg(DBG_DBG, "Copies until "<<revisionEOF<<" offset");
-	streamWriter->clone(file, 0, revisionEOF);
+	streamWriter->cloneToFile(file, 0, revisionEOF);
 
 	// adds pdf end of line marker to the output file
-	fwrite(EOFMARKER, sizeof(char), strlen(EOFMARKER), file);
+	size_t marker_len = strlen(EOFMARKER);
+	if(marker_len > fwrite(EOFMARKER, sizeof(char), marker_len, file))
+	{
+		int err = errno;
+		kernelPrintDbg(DBG_ERR, "Unable to write whole EOFMARKER (\"" << 
+				strerror(err) << "\").");
+	}
 	fflush(file);
 
 	// restore stream position
