@@ -1,173 +1,30 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 // vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 #ifndef _XREFWRITER_
 #define _XREFWRITER_
 
-/* 
- * $RCSfile: xrefwriter.h,v $
- *
- * $Log: xrefwriter.h,v $
- * Revision 1.28  2007/02/04 20:17:03  mstsxfx
- * Common Licence comment for all cc and h files available in doc/licence_header
- * file and its content to all cc and h files in src/{gui,kernel,utils}
- * directories.
- * Xpdf code, QSA and QOutputDevice code are not touched
- *
- * Revision 1.27  2006/07/12 18:27:17  hockm0bm
- * minor changes - code comments etc.
- *
- * Revision 1.26  2006/06/25 16:25:09  hockm0bm
- * doc update - doxygen warnings removed (if they are real problem)
- *
- * Revision 1.25  2006/06/01 14:46:24  hockm0bm
- * doc update - doxygen warnings removed (if possible)
- *
- * Revision 1.24  2006/05/17 19:40:07  hockm0bm
- * * getRevisionEnd
- *         - signature changed - uses position where to start searching
- *           not using current revision information
- *         - position is restored before return
- *         - method is protected now
- * * getRevisionSize method added
- *
- * Revision 1.23  2006/05/16 18:01:00  hockm0bm
- * pdf field value may be NULL - makes sense for stand alone XRefWriter instances
- *
- * Revision 1.22  2006/05/13 22:16:31  hockm0bm
- * * memory leak removed
- *         - changeObject didn't deallocate object returned from CXRef (previously changed value)
- *         - pdfWriter is deallocated in destructor
- * * ~XRefWriter destructor added
- * * log messages improved
- * * uses RefState
- *
- * Revision 1.21  2006/05/09 20:08:31  hockm0bm
- * * collectRevisions
- * 	- considers also xref streams
- * 	- checks for endless loop caused by wrong Trailer::Prev values (cycle)
- * * checkLinearized new parameter xref needed for proper parsing
- *
- * Revision 1.20  2006/05/08 22:21:56  hockm0bm
- * * isLinearized method added
- *         - linearized field added
- * * checkLinearized is called in constructor
- * * saveChages prints WARNING if file is linearized
- * * changeRevision throws an exception if file is linearized
- * * collectRevisions doesn't collect if file is linearized
- *
- * Revision 1.19  2006/05/08 21:24:33  hockm0bm
- * checkLinearized function added
- *
- * Revision 1.18  2006/05/08 20:17:42  hockm0bm
- * * key words removed from here
- * * new model of data writing
- *         - uses IPdfWriter interface for implementation specific writer
- *         - uses OldStylePdfWriter by default
- *         - new implementator can be set by setPdfWriter method
- *         - saveChanges collects object from changedStorage and uses IPdfWriter
- *           to write them to the stream so it is independed on implementation
- *
- * Revision 1.17  2006/05/06 08:40:20  hockm0bm
- * knowsRef delegates to XRef::knowsRef if not in the newest revision
- *
- * Revision 1.16  2006/04/27 18:21:09  hockm0bm
- * * deallocation of Object corrected
- * * changeRevision
- *         - saves revision
- *
- * Revision 1.15  2006/04/23 15:09:34  hockm0bm
- * note for getRefisionEOF method in documentation
- *
- * Revision 1.14  2006/04/23 13:13:20  hockm0bm
- * * getRevisionEnd method added
- *         - to get end of stream contnet for current revision
- * * cloneRevision method added
- *         - to support cloning of pdf in certain revision
- *
- * Revision 1.13  2006/04/19 06:00:23  hockm0bm
- * * changeRevision - first implementation (not tested yet)
- * * collectRevisions -  first implementation (not tested yet)
- * * minor changes in saveChanges
- *
- * Revision 1.12  2006/04/17 19:53:34  hockm0bm
- * documentation update
- *
- * Revision 1.11  2006/04/13 18:08:49  hockm0bm
- * * releaseObject method removed
- * * readOnly mode removed - makes no sense in here
- * * documentation updated
- * * contains information about CPdf
- *         - because of pdf read only mode
- * * buildXref method added
- * * XREFROWLENGHT and EOFMARKER macros added
- *
- * Revision 1.10  2006/04/12 17:52:25  hockm0bm
- * * saveChanges method replaces saveXRef method
- *         - new semantic for saving changes
- *              - temporary save
- *              - new revision save
- *         - storePos field added to mark starting
- *           place where to store changes
- *         - saveChanges moves with storePos if new
- *           revision is should be created
- * * findPDFEof function added
- * * StreamWriter in place of BaseStream
- *         - all changes will be done via StreamWriter
- *
- * Revision 1.9  2006/03/23 22:13:51  hockm0bm
- * printDbg added
- * exception handling
- * TODO removed
- * FIXME for revisions handling - throwing exeption
- *
- * Revision 1.8  2006/03/10 18:07:14  hockm0bm
- * reserveRef method added
- * createObject uses reserveRef
- * one FIXME in createObject - commented
- *
- * Revision 1.7  2006/03/08 12:09:24  misuj1am
- *
- * -- commented out unused arguments
- *
- * Revision 1.6  2006/03/07 18:29:27  hockm0bm
- * createObject returns CXref::createObject return value
- *
- * Revision 1.5  2006/03/06 18:18:55  hockm0bm
- * compilable changes - each module is compilable now
- * each object in pdfobjects namespace
- * more comments
- * cpdf - most of methods are just comments how to implement
- *
- * Revision 1.4  2006/02/28 19:52:10  hockm0bm
- * preparation for revision handling (kind of pseudocode)
- *	   - RevisionStorage type and field
- *	   - collectRevision method (pseudocode)
- *	   - getRevisionCount method
- *	   - getActualRevision method  (pseudocode)
- *	   - changeRevision method
- * methods depedning on changes are not available in older revisions
- *	   - error handling not solved yet - exception, return value?
- * saving new revision (pseudocode)
- *
- * Revision 1.3  2006/02/13 22:03:53  hockm0bm
- * Implementation moved to cc file
- *
- * Revision 1.2  2006/02/12 18:30:07  hockm0bm
- * first implementation (compileable) - not for real use
- *
- * Revision 1.1  2006/01/27 19:02:15  hockm0bm
- * writer class for the CXref class
- *
- *
- */
 
 /**
  * @file xrefwriter.h
@@ -175,10 +32,10 @@
  * Implementation of CXRef wrapper to enable making changes to the document.
  */
 
-#include "static.h"
-#include "cxref.h"
-#include "streamwriter.h"
-#include "pdfwriter.h"
+#include "kernel/static.h"
+#include "kernel/cxref.h"
+#include "kernel/streamwriter.h"
+#include "kernel/pdfwriter.h"
 
 
 namespace pdfobjects
@@ -326,6 +183,30 @@ protected:
 	 */
 	bool paranoidCheck(::Ref ref, ::Object * obj);
 
+	/** Parses old style trailer from given position.
+	 * @param trailer Previous trailer which will be filled with new data
+	 * 	(note that original content will be destroyed).
+	 * @param off File offset where to start.
+	 *
+	 * Note that file offset is assumed to point to the first byte of the
+	 * trailer object (exactly behind XREF_KEYWORD).
+	 * @return 0 on success, -1 otherwise.
+	 */
+	int getOldStyleTrailer(Object * trailer, size_t off);
+
+	/** Parses stream trailer from given position.
+	 * @param trailer Previous trailer which will be filled with new data
+	 * 	(note that original content will be destroyed).
+	 * @param off File offset of the trailer start.
+	 * @param parser Parser for the trailer.
+	 *
+	 * Note that parser has to point right behind first (object) number.
+	 * Then it assumes genereation number, `obj' keyword and trailer 
+	 * object definition.
+	 * @return 0 on success, -1 otherwise.
+	 */
+	int getStreamTrailer(Object * trailer, size_t off, ::Parser & parser);
+
 	/** Collects all revisions information.
 	 *
 	 * If linearized is set to true, immediately returns with warning message.
@@ -378,9 +259,7 @@ public:
 	 */
 	~XRefWriter()
 	{
-	using namespace debug;
-	
-		kernelPrintDbg(DBG_DBG, "");
+		kernelPrintDbg(debug::DBG_DBG, "");
 		if(pdfWriter)
 			delete pdfWriter;
 	}
@@ -631,7 +510,7 @@ public:
 	 * @see RefState
 	 * @return Reference state.
 	 */
-	virtual RefState knowsRef(::Ref ref)
+	virtual RefState knowsRef(::Ref& ref)
 	{
 		// if we are in newest revision, delegates to CXref
 		if(!revision)
