@@ -1,56 +1,27 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
- *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
-// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 /*
- * $RCSfile: rulesmanager.h,v $
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * $Log: rulesmanager.h,v $
- * Revision 1.9  2007/08/25 14:43:47  mstsxfx
- * formating
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
  *
- * Revision 1.8  2007/04/29 15:03:53  mstsxfx
- * TODO added
- *
- * Revision 1.7  2007/04/25 18:24:36  bilboq
- *
- * applied patch from Martin Michlmayr to fix compilation with gcc-4.3
- *
- * fixed some typos in comments
- *
- * Revision 1.6  2007/02/04 20:17:03  mstsxfx
- * Common Licence comment for all cc and h files available in doc/licence_header
- * file and its content to all cc and h files in src/{gui,kernel,utils}
- * directories.
- * Xpdf code, QSA and QOutputDevice code are not touched
- *
- * Revision 1.5  2006/06/25 16:25:21  hockm0bm
- * doc update - doxygen warnings removed (if they are real problem)
- *
- * Revision 1.4  2006/06/06 11:42:44  hockm0bm
- * * RulesManager
- *         - uses RuleType::operator== rather than RuleType::equals
- *           (to better fit ready to be used types like string)
- *
- * Revision 1.3  2006/06/06 10:14:05  hockm0bm
- * loadFromFile method added
- *         - generic implementation
- *
- * Revision 1.2  2006/05/31 21:43:55  hockm0bm
- * gcc
- *
- * Revision 1.1  2006/05/31 14:11:19  hockm0bm
- * * IRuleMatcher abstract class
- * * RulesManager generic implementation
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
  *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
+// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 #ifndef _RULESMANAGER_H_
 #define _RULESMANAGER_H_
 
@@ -265,17 +236,16 @@ public:
 	template<typename Parser>
 	int loadFromFile(const std::string & confFile, Parser & parser)
 	{
-	using namespace std;
 
 		int added=0;
 
 		// opens input stream
-		ifstream stream(confFile.c_str());
+		std::ifstream stream(confFile.c_str());
 		if(!stream.is_open())
 			return -1;
 		
 		// uses opened input file stream
-		istream * original=parser.setStream(&stream);
+		std::istream * original=parser.setStream(&stream);
 
 		// parses all rules and register them by super type interface
 		while(!parser.eod())
@@ -352,8 +322,7 @@ public:
 		for(; i!=mapping.end(); )
 		{
 			const RuleType original=i->first;
-			RuleMatcherType & matcher=matcher;
-			if(matcher(original, ruleDef, NULL))
+			if((*matcher)(original, ruleDef, NULL))
 			{
 				// this element matches
 				if(removed)
@@ -366,7 +335,7 @@ public:
 			}
 
 			// doesn't match, simply moves iterator
-			i++;
+			++i;
 		}
 	}
 
